------------------------------------------------------------------------------------------------------------------------

-- VN_670428_Khe_Sanh.lua

-- Author: Jason Petho	
-- Scripter: Jason Petho
-- Date: 20210608

------------------------------------------------------------------------------------------------------------------------

function on_startup () -- DO NOT REMOVE

    -- set/unset optional rules (effective in on_startup() only!)
    -- for example:
    -- set_option(OPTHISTORICALLZS)
    -- unset_option(OPTFACING)
    -- to specify every optional rule:
    -- set_options(OPTFIREMAP|OPTEXTFOW|OPTCOMMANDCTRL|OPTVISIBILITY)

    -- set/unset move tracking globally (maybe unset if performance lags)
    -- set_move_tracking()
    -- unset_move_tracking()

    -- for deep debugging:
    --traceon()

    init_constants ()
    init_variables ()

    set_org_lists()

end

------------------------------------------------------------------------------------------------------------------------

function on_resume () -- DO NOT REMOVE

    -- see on_startup()
    -- set_move_tracking()
    -- unset_move_tracking()

    -- for deep debugging:
    --traceon()

    init_constants ()

    set_org_lists(current_turn(), current_side())

end

------------------------------------------------------------------------------------------------------------------------

function init_constants ()

    -- initialize names and labels unvarying through the course of the scenario
    -- also define here lists with "holes" (index gaps) (such lists are not saved)
    -- called in on_startup(), and potentially again (and again) in any subsequent on_resume()

    -- Side "a" and "b" values with descriptive names
    SIDE_A = "a" -- _NATION ## (in user.lua)
    US_SIDE = SIDE_A
    ARVN_SIDE = SIDE_A
    SIDE_B = "b" -- _NATION ## (in user.lua)
    VC_SIDE = SIDE_B
    NVA_SIDE = SIDE_B

    OBJECTIVES = {}
    OBJECTIVES[1] = "45,49" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[2] = "47,46" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[3] = "47,48" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[4] = "48,53" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[5] = "49,51" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[6] = "50,46" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[7] = "51,52" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[8] = "52,43" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[9] = "52,48" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[10] = "54,51" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[11] = "56,46" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[12] = "57,51" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21
    OBJECTIVES[13] = "57,54" -- 1-15[1/1] 16-27[1/1] 28-40[1/1] 21

    LANDING_ZONES = {}
    LANDING_ZONES[1] = "51,54"
    LANDING_ZONES[2] = "57,52"
    LANDING_ZONES[3] = "75,62"
    LANDING_ZONES[4] = "76,62"
    LANDING_ZONES[5] = "77,63"
    LANDING_ZONES[6] = "78,63"

    EMBARK_PTS = {}
    -- and also, for example (indexing from 1 thru x):
    -- Side A
    -- EMBARK_PTS[1] = "45,69"
    -- ...
    -- Side B
    -- ...
    -- EMBARK_PTS[x] = "20,48"

    DISEMBARK_PTS = {}
    -- and also, for example (indexing from 1 thru x):
    -- Side A
    -- DISEMBARK_PTS[1] = "41,69"
    -- ...
    -- Side B
    -- ...
    -- DISEMBARK_PTS[x] = "13,56"

    -- others ...
    
    LANG_RUON = {OBJECTIVES[1]}
    XOM_BONG = {OBJECTIVES[8]}
    HILL_516 = {OBJECTIVES[11]}
    HILL_700 = {OBJECTIVES[13]}
    HILL_861 = {OBJECTIVES[10], OBJECTIVES[12]}
    HILL_861_SADDLE = {OBJECTIVES[6], OBJECTIVES[9]}
    HILL_881_NORTH = {OBJECTIVES[2], OBJECTIVES[3]}
    HILL_881_SOUTH = {OBJECTIVES[4], OBJECTIVES[5], OBJECTIVES[7]}

end

------------------------------------------------------------------------------------------------------------------------

function set_org_lists (turn, side)

    -- called in on_startup(), in every on_next_turn(), and potentially again (and again) in any subsequent on_resume()

    --traceon()

    turn = turn or 1
    side = side or "a"

    ALLA = counters_all(SIDE_A)
    ALLB = counters_all(SIDE_B)

    -- auto-generated org lists to follow; rename, resequence, regroup, and reorganize as necessary

    -- KEY:

    -- [P] Platoon
    -- [C] Company
    -- [B] Battalion
    -- [R] Regiment
    -- [G] Brigade
    -- [D] Division
    -- [K] Corps
    -- [A] Army

    _KHE_SANH_COMBAT_BASE_AND_AREA_215 = {216,521,117,118,128,129,130,131,132,135,136,137,138,139,142,143,144,145,146,202,203,204,205,206,156,157,2121,2122,174,175,176,177,178,2163,209,210,211,212,213,532,533,534,535,536,188,2108,2109,2110,71,72,523,525,530,529,2161,2157,2158,2159,594,595,596,597,2123,2,42,4,5,6,7,8,22,23,26,30,34,40,41,39,37,38,561,593,544,543,542,552,553,554,605,556,557,558,559} -- [G] [1032001] Khe Sanh Combat Base - and area

    _BRG_HQ_216 = {216} -- [P] [75,63] [103015] Brigade HQ (foot)

    _M35_521 = {521} -- [P] [75,63] [107040] 2 1/2 ton truck armed

    _3RD_MARINE_INF_RGT_67_43 = {117,118,128,129,130,131,132,135,136,137,138,139,142,143,144,145,146,202,203,204,205,206,156,157,2121,2122,174,175,176,177,178,2163,209,210,211,212,213,532,533,534,535,536,188,2108,2109,2110,71,72} -- [R] [1022261] 3rd Marine Infantry Regiment 67

    _2ND_3RD_MARINE_BTN_66_MARINES_116 = {117,118,128,129,130,131,132,135,136,137,138,139,142,143,144,145,146,202,203,204,205,206} -- [B] [1012311] 2nd/3rd Marine Battalion 66 - MARINES

    _BTN_HQ_117 = {117} -- [P] [65,56] [103311] Battalion HQ (foot)

    _2ND_3RD_MARINE_118 = {118} -- [P] [65,56] [104301] Commander 1

    _E_2ND_3RD_MARINE_INF_COY_66_127 = {128,129,130,131,132} -- [C] [1002385] E/2nd/3rd Marine Infantry Company 66
    _1ST_PLT_128 = {128} -- [P] [64,55] [102606] Marine Platoon 66
    _2ND_PLT_129 = {129} -- [P] [64,55] [102606] Marine Platoon 66
    _3RD_PLT_130 = {130} -- [P] [65,55] [102606] Marine Platoon 66
    _1_WEAPONS_PLT_131 = {131} -- [P] [64,55] [102637] M60 Machine Gun
    _2_WEAPONS_PLT_132 = {132} -- [P] [65,55] [102637] M60 Machine Gun

    _F_2ND_3RD_MARINE_INF_COY_66_134 = {135,136,137,138,139} -- [C] [1002385] F/2nd/3rd Marine Infantry Company 66
    _1ST_PLT_135 = {135} -- [P] [64,56] [102606] Marine Platoon 66
    _2ND_PLT_136 = {136} -- [P] [64,56] [102606] Marine Platoon 66
    _3RD_PLT_137 = {137} -- [P] [63,56] [102606] Marine Platoon 66
    _1_WEAPONS_PLT_138 = {138} -- [P] [63,56] [102637] M60 Machine Gun
    _2_WEAPONS_PLT_139 = {139} -- [P] [63,56] [102637] M60 Machine Gun

    _G_2ND_3RD_MARINE_INF_COY_66_141 = {142,143,144,145,146} -- [C] [1002385] G/2nd/3rd Marine Infantry Company 66
    _1ST_PLT_142 = {142} -- [P] [67,56] [102606] Marine Platoon 66
    _2ND_PLT_143 = {143} -- [P] [67,56] [102606] Marine Platoon 66
    _3RD_PLT_144 = {144} -- [P] [66,55] [102606] Marine Platoon 66
    _1_WEAPONS_PLT_145 = {145} -- [P] [67,56] [102637] M60 Machine Gun
    _2_WEAPONS_PLT_146 = {146} -- [P] [66,55] [102637] M60 Machine Gun

    _H_2ND_3RD_MARINE_INF_COY_66_MARINES_0VP_201 = {202,203,204,205,206} -- [C] [1002385] H/2nd/3rd Marine Infantry Company 66 - MARINES - 0VP
    _1ST_PLT_202 = {202} -- [P] [73,62] [102606] Marine Platoon 66
    _2ND_PLT_203 = {203} -- [P] [75,61] [102606] Marine Platoon 66
    _3RD_PLT_204 = {204} -- [P] [77,64] [102606] Marine Platoon 66
    _1_WEAPONS_PLT_205 = {205} -- [P] [73,62] [102637] M60 Machine Gun
    _2_WEAPONS_PLT_206 = {206} -- [P] [75,61] [102637] M60 Machine Gun

    _3RD_3RD_MARINE_BTN_66_MARINES_155 = {156,157,2121,2122,174,175,176,177,178,2163,209,210,211,212,213,532,533,534,535,536,188} -- [B] [1012311] 3rd/3rd Marine Battalion 66 - MARINES

    _BTN_HQ_156 = {156} -- [P] [71,62] [103311] Battalion HQ (foot)

    _3RD_3RD_MARINE_157 = {157} -- [P] [71,62] [104301] Commander 1

    _HQ_AND_SERVICE_COY_62_MARINE_158 = {2121,2122} -- [C] [1002326] Headquarters and Service Company 62 - Marine
    _M274_106MM_RR_2121 = {2121} -- [P] [75,62] [109516] M274 106mm Recoilless Rifle
    _M274_106MM_RR_2122 = {2122} -- [P] [76,62] [109516] M274 106mm Recoilless Rifle

    _K_3RD_3RD_MARINE_INF_COY_66_173 = {174,175,176,177,178} -- [C] [1002385] K/3rd/3rd Marine Infantry Company 66
    _1ST_PLT_174 = {174} -- [P] [68,61] [102606] Marine Platoon 66
    _2ND_PLT_175 = {175} -- [P] [68,61] [102606] Marine Platoon 66
    _3RD_PLT_176 = {176} -- [P] [69,62] [102606] Marine Platoon 66
    _1_WEAPONS_PLT_177 = {177} -- [P] [68,61] [102637] M60 Machine Gun
    _2_WEAPONS_PLT_178 = {178} -- [P] [69,62] [102637] M60 Machine Gun

    _M_3RD_3RD_MARINE_INF_COY_66_MARINES_0VP_208 = {2163,209,210,211,212,213} -- [C] [1002385] M/3rd/3rd Marine Infantry Company 66 - MARINES - 0VP
    _M_3RD_3RD_2163 = {2163} -- [P] [71,63] [104401] Commander 1
    _1ST_PLT_209 = {209} -- [P] [71,63] [102606] Marine Platoon 66
    _2ND_PLT_210 = {210} -- [P] [71,63] [102606] Marine Platoon 66
    _3RD_PLT_211 = {211} -- [P] [70,62] [102606] Marine Platoon 66
    _1_WEAPONS_PLT_212 = {212} -- [P] [70,62] [102637] M60 Machine Gun
    _2_WEAPONS_PLT_213 = {213} -- [P] [70,62] [102637] M60 Machine Gun

    _M_3RD_9TH_MARINE_INF_COY_66_MARINES_0VP_531 = {532,533,534,535,536} -- [C] [1002385] M/3rd/9th Marine Infantry Company 66 - MARINES - 0VP
    _1ST_PLT_532 = {532} -- [P] [71,62] [102606] Marine Platoon 66
    _2ND_PLT_533 = {533} -- [P] [70,61] [102606] Marine Platoon 66
    _3RD_PLT_534 = {534} -- [P] [71,62] [102606] Marine Platoon 66
    _1_WEAPONS_PLT_535 = {535} -- [P] [70,61] [102637] M60 Machine Gun
    _2_WEAPONS_PLT_536 = {536} -- [P] [71,62] [102637] M60 Machine Gun

    _LOGISTICS_COY_LEVEL_1_62_MARINES_187 = {188} -- [C] [1009300] Logistics Company - Level 1 - 62 - MARINES

    _SUPPLY_TRUCKS_188 = {188} -- [P] [76,62] [107575] Supply Trucks (VP)

    _ENGINEER_COY_66_MARINES_2107 = {2108,2109,2110} -- [C] [1005316] Engineer Company 66 - MARINES
    _1ST_PLT_2108 = {2108} -- [P] [65,56] [102621] Engineer Platoon 66
    _2ND_PLT_2109 = {2109} -- [P] [66,55] [102621] Engineer Platoon 66
    _3RD_PLT_2110 = {2110} -- [P] [70,61] [102621] Engineer Platoon 66

    _LOGISTICS_COY_LEVEL_2_62_MARINES_67 = {71,72} -- [C] [1009301] Logistics Company - Level 2 - 62 - MARINES
    _SUPPLY_CACHE_71 = {71} -- [P] [78,63] [108804] Supply Cache (VP)
    _SUPPLY_CACHE_72 = {72} -- [P] [77,63] [108804] Supply Cache (VP)

    _F_2ND_12TH_FIELD_ARTILLERY_BTY_66_M101_M35_MARINES_0VP_522 = {523,525,530,529} -- [C] [1001345] F/2nd/12th Field Artillery Battery 66 - M101/M35 - MARINES - 0VP
    _M101_105MM_HOWITZERS_523 = {523} -- [P] [77,64] [101660] M101 105mm Howitzers
    _M114_155MM_HOWITZERS_525 = {525} -- [P] [77,64] [101668] M114 155mm Howitzers
    _42_INCH_MORTARS_530 = {530} -- [P] [74,63] [101655] M30 4.2-inch Mortars
    _M60_529 = {529} -- [P] [77,64] [102638] M60 Machine Gun

    _M101_105MM_HOWITZERS_2161 = {2161} -- [P] [76,63] [101660] M101 105mm Howitzers

    _3RD_MARINE_RECONNAISSANCE_COY_66_MARINES_0VP_2156 = {2157,2158,2159} -- [C] [1002387] 3rd Marine Reconnaissance Company 66 - MARINES - 0VP
    _MARINE_RECONNAISSANCE_2157 = {2157} -- [P] [77,62] [102609] Marine Reconnaissance 65
    _MARINE_RECONNAISSANCE_2158 = {2158} -- [P] [73,62] [102609] Marine Reconnaissance 65
    _MARINE_RECONNAISSANCE_2159 = {2159} -- [P] [74,63] [102609] Marine Reconnaissance 65

    _3RD_B_1ST_AMPHIBIAN_TRACTOR_BTN_594 = {594} -- [P] [76,63] [107585] LVTP-5

    _2ND_A_3RD_ANTITANK_BTN_595 = {595} -- [P] [75,63] [109501] M50A1 Ontos SPMRR

    _3RD_B_3RD_RECONNAISSANCE_BTN_596 = {596} -- [P] [75,63] [102609] Marine Reconnaissance 65

    _3RD_B_3RD_RECONNAISSANCE_BTN_M151_597 = {597} -- [P] [75,63] [107554] 1/4 ton truck

    _M35A2_M55_SPAA_2123 = {2123} -- [P] [76,63] [108308] M35A2/M55 SPAA

    _LANG_VIE_SPECIAL_FORCES_CAMP_1 = {2,42,4,5,6,7,8,22,23,26,30,34,40,41,39,37,38} -- [B] [1112281] Lang Vie Special Forces Camp

    _HQ_2 = {2} -- [P] [49,88] [113025] Mike Force Battalion HQ (foot)

    _US_ADVISOR_42 = {42} -- [P] [49,88] [104002] Commander 2

    _1ST_MOBILE_STRIKE_FORCE_COY_66_3 = {4,5,6,7,8} -- [C] [1102306] 1st Mobile Strike Force Company 66
    _1ST_PLT_4 = {4} -- [P] [45,89] [112075] Mobile Strike Force Platoon 66
    _2ND_PLT_5 = {5} -- [P] [45,89] [112075] Mobile Strike Force Platoon 66
    _3RD_PLT_6 = {6} -- [P] [55,86] [112075] Mobile Strike Force Platoon 66
    _RECONNAISSANCE_7 = {7} -- [P] [55,86] [112091] Mobile Strike Force Reconnaissance
    _GPMG_8 = {8} -- [P] [45,89] [112090] Mike Force M-60 Machine Gun

    _CIDG_COY_101_21 = {22,23} -- [C] [1102295] CIDG Company 101
    _1ST_PLT_41_22 = {22} -- [P] [48,87] [112045] CIDG Platoon 64
    _2ND_PLT_41_23 = {23} -- [P] [48,87] [112045] CIDG Platoon 64

    _CIDG_COY_102_25 = {26} -- [C] [1102295] CIDG Company 102

    _1ST_PLT_42_26 = {26} -- [P] [49,88] [112045] CIDG Platoon 64

    _CIDG_COY_103_29 = {30} -- [C] [1102295] CIDG Company 103

    _1ST_PLT_43_30 = {30} -- [P] [49,88] [112045] CIDG Platoon 64

    _CIDG_COY_104_33 = {34} -- [C] [1102295] CIDG Company 104

    _1ST_PLT_44_34 = {34} -- [P] [48,87] [112045] CIDG Platoon 64

    _SPECIAL_FORCES_TEAM_A101_40 = {40} -- [P] [48,87] [102087] Special Forces Team

    _SPECIAL_FORCES_TEAM_A101_41 = {41} -- [P] [49,88] [102087] Special Forces Team

    _M1_81MM_MORTARS_3_39 = {39} -- [P] [49,88] [111010] M1 81mm Mortars

    _M40_106MM_RCLR_37 = {37} -- [P] [48,87] [119015] CIDG M67 90mm Recoilless Rifle

    _M2_42_INCH_MORTARS_38 = {38} -- [P] [49,88] [111014] M2 4.2-inch Mortars

    _KHE_SANH_VILLAGE_560 = {561,593,544,543,542,552,553,554,605,556,557,558,559} -- [B] [1112001] Khe Sanh Village

    _HQ_561 = {561} -- [P] [79,78] [113010] ARVN Battalion HQ (foot)

    _US_ADVISOR_593 = {593} -- [P] [79,78] [104301] Commander 1

    _COMBINED_ACTION_COY_OSCAR_545 = {544,543,542,552,553,554} -- [C] [1102311] Combined Action Company Oscar
    _MARINE_FIRE_TEAM_544 = {544} -- [P] [70,71] [102616] Marine Reconnaissance 66
    _MARINE_FIRE_TEAM_543 = {543} -- [P] [79,77] [102616] Marine Reconnaissance 66
    _MARINE_FIRE_TEAM_542 = {542} -- [P] [79,78] [102616] Marine Reconnaissance 66
    _POPULAR_FORCE_552 = {552} -- [P] [70,71] [112061] Popular Forces Platoon 64
    _POPULAR_FORCE_553 = {553} -- [P] [79,77] [112061] Popular Forces Platoon 64
    _POPULAR_FORCE_554 = {554} -- [P] [79,78] [112061] Popular Forces Platoon 64

    _REGIONAL_FORCE_COY_64_II_0VP_555 = {605,556,557,558,559} -- [C] [1102297] Regional Force Company 64 - II - 0VP
    _US_ADVISOR_605 = {605} -- [P] [79,77] [104001] Commander 1
    _1ST_PLT_556 = {556} -- [P] [79,77] [112058] Regional Forces Platoon 64 F
    _2ND_PLT_557 = {557} -- [P] [79,77] [112058] Regional Forces Platoon 64 F
    _3RD_PLT_558 = {558} -- [P] [79,78] [112059] Regional Forces Platoon 64 US
    _MMG_48_559 = {559} -- [P] [79,78] [112089] Regional Forces M1919A6 Machine Gun

    _FSB_ROCKPILE_2ND_94TH_538 = {539,540,541} -- [C] [1001330] FSB Rockpile - 2nd/94th
    _M107_539 = {539} -- [P] [131,22] [101029] M107 Self-Propelled 175mm
    _M107_540 = {540} -- [P] [131,21] [101030] M107 Self-Propelled 175mm
    _M109_541 = {541} -- [P] [132,21] [101016] M109 Self-Propelled 155mm

    _BTN_HQ_2126 = {2126} -- [P] [76,62] [103311] Battalion HQ (foot)

    _UH1E_2127 = {2127} -- [P] [T10: 149,51] [106723] UH-1E Gunship Rockets

    _UH34_2150 = {2150} -- [P] [T998: 149,49] [106706] CH-34 Choctaw

    _CH46_2143 = {2143} -- [P] [T999: 149,51] [106720] CH-46 Sea Knight

    _DIV_325_NVA_67_971 = {1291,1292,1294,2100,1296,1297,1298,1301,1303,1304,1305,1307,1308,1310,1311,1312,1315,1317,1318,1319,1320,1321,1322,1332,1333,1334,1336,2105,1338,1339,1340,1343,1345,1346,1347,1350,1352,1353,1354,1357,1359,1360,1361,1362,1363,1364,1374,1375,1376,1420,1421,1422,1423,1429,1433,1441,1442,1443,1445,1446,1450,1468} -- [D] [2142248] Division 325 - NVA 67

    _RGT_18C_NVA_REGULAR_INF_RGT_67_AK_B_SVN_I_CORPS_DIV_325_QUANG_TRI_1290 = {1291,1292,1294,2100,1296,1297,1298,1301,1303,1304,1305,1307,1308,1310,1311,1312,1315,1317,1318,1319,1320,1321,1322,1332,1333,1334,1336,2105,1338,1339,1340,1343,1345,1346,1347,1350,1352,1353,1354,1357,1359,1360,1361,1362,1363,1364,1374,1375,1376,1420,1421,1422,1423,1429,1433,1441,1442,1443,1445,1446,1450,1468} -- [R] [2122370] Regiment 18C - NVA Regular Infantry Regiment 67 - AK - B - SVN I Corps/Division 325/Quang Tri

    _TRUNG_DOAN_HQ_1291 = {1291} -- [P] [43,46] [213007] NVA Regimental HQ (foot)

    _R18C_1292 = {1292} -- [P] [43,46] [214002] NVA Commander 2

    _D7_R18C_NVA_REGULAR_INF_BTN_67_AK_1293 = {1294,2100,1296,1297,1298,1301,1303,1304,1305,1307,1308,1310,1311,1312,1315,1317,1318,1319,1320,1321,1322,1332,1333,1334} -- [B] [2112293] D7/R18C NVA Regular Infantry Battalion 67 - AK

    _TIEU_DOAN_HQ_1294 = {1294} -- [P] [48,53] [213010] NVA Battalion HQ (foot)

    _D7_R18C_2100 = {2100} -- [P] [48,53] [214001] NVA Commander 1

    _C1_NVA_RIFLE_COY_67_AK_B_SVN_1295 = {1296,1297,1298,1301} -- [C] [2102338] C1 NVA Rifle Company 67 - AK - B - SVN
    _1ST_PLT_1296 = {1296} -- [P] [50,53] [212124] NVA Rifle Platoon 67 B
    _2ND_PLT_1297 = {1297} -- [P] [52,53] [212124] NVA Rifle Platoon 67 B
    _3RD_PLT_1298 = {1298} -- [P] [52,54] [212124] NVA Rifle Platoon 67 B
    _FIRE_SUPPORT_MMG_1301 = {1301} -- [P] [52,53] [212009] NVA Medium Machine Gun

    _C2_NVA_RIFLE_COY_67_AK_B_SVN_1302 = {1303,1304,1305,1307,1308} -- [C] [2102338] C2 NVA Rifle Company 67 - AK - B - SVN
    _1ST_PLT_1303 = {1303} -- [P] [48,52] [212124] NVA Rifle Platoon 67 B
    _2ND_PLT_1304 = {1304} -- [P] [47,53] [212124] NVA Rifle Platoon 67 B
    _3RD_PLT_1305 = {1305} -- [P] [48,54] [212124] NVA Rifle Platoon 67 B
    _FIRE_SUPPORT_RPG7_1307 = {1307} -- [P] [48,53] [219022] RPG-7 Team
    _FIRE_SUPPORT_MMG_1308 = {1308} -- [P] [48,53] [212009] NVA Medium Machine Gun

    _C3_NVA_RIFLE_COY_67_AK_B_SVN_1309 = {1310,1311,1312,1315} -- [C] [2102338] C3 NVA Rifle Company 67 - AK - B - SVN
    _1ST_PLT_1310 = {1310} -- [P] [50,50] [212124] NVA Rifle Platoon 67 B
    _2ND_PLT_1311 = {1311} -- [P] [48,50] [212124] NVA Rifle Platoon 67 B
    _3RD_PLT_1312 = {1312} -- [P] [47,51] [212124] NVA Rifle Platoon 67 B
    _FIRE_SUPPORT_MMG_1315 = {1315} -- [P] [51,52] [212009] NVA Medium Machine Gun

    _C4_NVA_FIRE_SUPPORT_COY_64_SVN_1316 = {1317,1318,1319,1320,1321,1322} -- [C] [2102332] C4 NVA Fire Support Company 64 - SVN
    _82MM_MORTARS_1317 = {1317} -- [P] [45,49] [211019] 82mm Mortars
    _75MM_RCLR_1318 = {1318} -- [P] [50,52] [219011] 75mm Recoilless Rifles
    _NVA_HMG_1319 = {1319} -- [P] [50,52] [212010] NVA Heavy Machine Gun
    _SNIPER_1320 = {1320} -- [P] [49,56] [212023] NVA Sniper
    _SNIPER_1321 = {1321} -- [P] [45,52] [212023] NVA Sniper
    _SNIPER_1322 = {1322} -- [P] [50,50] [212023] NVA Sniper

    _DAC_CONG_1332 = {1332} -- [P] [45,46] [212002] NVA Sapper Platoon 63

    _THAM_BAO_1333 = {1333} -- [P] [47,47] [212122] NVA Reconnaissane Platoon 67

    _SNIPER_1334 = {1334} -- [P] [47,47] [212023] NVA Sniper

    _D8_R18C_NVA_REGULAR_INF_BTN_67_AK_1335 = {1336,2105,1338,1339,1340,1343,1345,1346,1347,1350,1352,1353,1354,1357,1359,1360,1361,1362,1363,1364,1374,1375,1376} -- [B] [2112293] D8/R18C NVA Regular Infantry Battalion 67 - AK

    _TIEU_DOAN_HQ_1336 = {1336} -- [P] [45,45] [213010] NVA Battalion HQ (foot)

    _D8_R18C_2105 = {2105} -- [P] [45,45] [214002] NVA Commander 2

    _C1_NVA_RIFLE_COY_67_AK_B_SVN_1337 = {1338,1339,1340,1343} -- [C] [2102338] C1 NVA Rifle Company 67 - AK - B - SVN
    _1ST_PLT_1338 = {1338} -- [P] [56,46] [212124] NVA Rifle Platoon 67 B
    _2ND_PLT_1339 = {1339} -- [P] [54,48] [212124] NVA Rifle Platoon 67 B
    _3RD_PLT_1340 = {1340} -- [P] [51,47] [212124] NVA Rifle Platoon 67 B
    _FIRE_SUPPORT_MMG_1343 = {1343} -- [P] [54,48] [212009] NVA Medium Machine Gun

    _C2_NVA_RIFLE_COY_67_AK_B_SVN_1344 = {1345,1346,1347,1350} -- [C] [2102338] C2 NVA Rifle Company 67 - AK - B - SVN
    _1ST_PLT_1345 = {1345} -- [P] [52,48] [212124] NVA Rifle Platoon 67 B
    _2ND_PLT_1346 = {1346} -- [P] [54,49] [212124] NVA Rifle Platoon 67 B
    _3RD_PLT_1347 = {1347} -- [P] [51,49] [212124] NVA Rifle Platoon 67 B
    _FIRE_SUPPORT_MMG_1350 = {1350} -- [P] [53,49] [212009] NVA Medium Machine Gun

    _C3_NVA_RIFLE_COY_67_AK_B_SVN_1351 = {1352,1353,1354,1357} -- [C] [2102338] C3 NVA Rifle Company 67 - AK - B - SVN
    _1ST_PLT_1352 = {1352} -- [P] [47,48] [212124] NVA Rifle Platoon 67 B
    _2ND_PLT_1353 = {1353} -- [P] [47,46] [212124] NVA Rifle Platoon 67 B
    _3RD_PLT_1354 = {1354} -- [P] [46,46] [212124] NVA Rifle Platoon 67 B
    _FIRE_SUPPORT_MMG_1357 = {1357} -- [P] [47,46] [212009] NVA Medium Machine Gun

    _C4_NVA_FIRE_SUPPORT_COY_64_SVN_1358 = {1359,1360,1361,1362,1363,1364} -- [C] [2102332] C4 NVA Fire Support Company 64 - SVN
    _82MM_MORTARS_1359 = {1359} -- [P] [46,45] [211019] 82mm Mortars
    _75MM_RCLR_1360 = {1360} -- [P] [47,48] [219011] 75mm Recoilless Rifles
    _NVA_HMG_1361 = {1361} -- [P] [56,50] [212010] NVA Heavy Machine Gun
    _SNIPER_1362 = {1362} -- [P] [54,51] [212023] NVA Sniper
    _SNIPER_1363 = {1363} -- [P] [47,45] [212023] NVA Sniper
    _SNIPER_1364 = {1364} -- [P] [51,45] [212023] NVA Sniper

    _DAC_CONG_1374 = {1374} -- [P] [50,46] [212002] NVA Sapper Platoon 63

    _THAM_BAO_1375 = {1375} -- [P] [52,48] [212122] NVA Reconnaissane Platoon 67

    _SNIPER_1376 = {1376} -- [P] [45,45] [212023] NVA Sniper

    _NVA_ANTIAIRCRAFT_COY_64_127MM_PORTERS_1419 = {1420,1421,1422,1423} -- [C] [2108250] NVA Anti-Aircraft Company 64 - 12.7mm/Porters
    _NVA_AAMG_PLTN_1420 = {1420} -- [P] [47,45] [212021] NVA Anti-Aircraft Machine Gun
    _NVA_AAMG_PLTN_1421 = {1421} -- [P] [48,54] [212021] NVA Anti-Aircraft Machine Gun
    _NVA_AAMG_PLTN_1422 = {1422} -- [P] [51,47] [212021] NVA Anti-Aircraft Machine Gun
    _NVA_AAMG_PLTN_1423 = {1423} -- [P] [46,45] [212021] NVA Anti-Aircraft Machine Gun

    _NVA_RECONNAISSANCE_COY_67_1428 = {1429,1433} -- [C] [2106219] NVA Reconnaissance Company 67
    _1ST_PLT_1429 = {1429} -- [P] [49,45] [212122] NVA Reconnaissane Platoon 67
    _FIRE_SUPPORT_MMG_1433 = {1433} -- [P] [49,45] [212009] NVA Medium Machine Gun

    _NVA_MACHINE_GUN_COY_64_SVN_1440 = {1441,1442,1443} -- [C] [2102340] NVA Machine Gun Company 64 - SVN
    _NVA_HMG_1441 = {1441} -- [P] [52,46] [212010] NVA Heavy Machine Gun
    _NVA_HMG_1442 = {1442} -- [P] [51,49] [212010] NVA Heavy Machine Gun
    _NVA_HMG_1443 = {1443} -- [P] [44,49] [212010] NVA Heavy Machine Gun

    _NVA_RECOILLESS_RIFLE_COY_64_B10_1444 = {1445,1446} -- [C] [2103221] NVA Recoilless Rifle Company 64 - B-10
    _B10_1445 = {1445} -- [P] [54,49] [219013] B-10 82mm Recoilless Anti-Tank Gun
    _B10_1446 = {1446} -- [P] [44,49] [219013] B-10 82mm Recoilless Anti-Tank Gun

    _MORTAR_BTY_64_82MMX9_1449 = {1450} -- [C] [2101268] Mortar Battery 64 - 82mmx9

    _82MM_MORTARS_1450 = {1450} -- [P] [45,49] [211019] 82mm Mortars

    _AAMG_1468 = {1468} -- [P] [48,52] [212021] NVA Anti-Aircraft Machine Gun

    _TRAILPORTERS_1454 = {1454} -- [P] [8,46] [212021] NVA Anti-Aircraft Machine Gun
    _TRAILPORTERS_1455 = {1455} -- [P] [9,47] [212021] NVA Anti-Aircraft Machine Gun

    _VOUGHT_F8_CRUSADER_BOMBS_2165 = {2165} -- [P] [9999,9999] [105026] Vought F-8 Crusader {Bombs}

    _VOUGHT_F8_CRUSADER_BOMBS_2166 = {2166} -- [P] [9999,9999] [105026] Vought F-8 Crusader {Bombs}

    _VOUGHT_F8_CRUSADER_BOMBS_2167 = {2167} -- [P] [9999,9999] [105026] Vought F-8 Crusader {Bombs}

    _VOUGHT_F8_CRUSADER_BOMBS_2168 = {2168} -- [P] [9999,9999] [105026] Vought F-8 Crusader {Bombs}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2169 = {2169} -- [P] [9999,9999] [105044] USAF McDonnell Douglas F-4E Phantom II {Napalm}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2170 = {2170} -- [P] [9999,9999] [105044] USAF McDonnell Douglas F-4E Phantom II {Napalm}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2171 = {2171} -- [P] [9999,9999] [105044] USAF McDonnell Douglas F-4E Phantom II {Napalm}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2172 = {2172} -- [P] [9999,9999] [105044] USAF McDonnell Douglas F-4E Phantom II {Napalm}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2173 = {2173} -- [P] [9999,9999] [105044] USAF McDonnell Douglas F-4E Phantom II {Napalm}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2174 = {2174} -- [P] [9999,9999] [105044] USAF McDonnell Douglas F-4E Phantom II {Napalm}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2175 = {2175} -- [P] [9999,9999] [105044] USAF McDonnell Douglas F-4E Phantom II {Napalm}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2176 = {2176} -- [P] [9999,9999] [105042] USAF McDonnell Douglas F-4E Phantom II {Bombs}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2177 = {2177} -- [P] [9999,9999] [105042] USAF McDonnell Douglas F-4E Phantom II {Bombs}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2178 = {2178} -- [P] [9999,9999] [105042] USAF McDonnell Douglas F-4E Phantom II {Bombs}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2179 = {2179} -- [P] [9999,9999] [105042] USAF McDonnell Douglas F-4E Phantom II {Bombs}

    _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2180 = {2180} -- [P] [9999,9999] [105042] USAF McDonnell Douglas F-4E Phantom II {Bombs}

    _VOUGHT_F8_CRUSADER_BOMBS_2181 = {2181} -- [P] [9999,9999] [105026] Vought F-8 Crusader {Bombs}

    _VOUGHT_F8_CRUSADER_BOMBS_2182 = {2182} -- [P] [9999,9999] [105026] Vought F-8 Crusader {Bombs}

    _VOUGHT_F8_CRUSADER_BOMBS_2183 = {2183} -- [P] [9999,9999] [105026] Vought F-8 Crusader {Bombs}

    _VOUGHT_F8_CRUSADER_BOMBS_2184 = {2184} -- [P] [9999,9999] [105026] Vought F-8 Crusader {Bombs}

    _VOUGHT_F8_CRUSADER_BOMBS_2185 = {2185} -- [P] [9999,9999] [105026] Vought F-8 Crusader {Bombs}

    -- hand-crafted org lists, if any, to follow

    --traceoff()
    
    US_COYS = {127,134,141,173,201,208,531,598}
	NVA_COYS = {1295,1302,1309,1337,1344,1351,1358} 

end

------------------------------------------------------------------------------------------------------------------------

function init_variables ()

    -- initialize values possibly varying through the course of the scenario
    -- called once only, in on_startup()

    -- embark/disembark points
    -- for example:
    -- _D303_VC_MAIN_FORCE_INF_BTN_2ND_RIFLE_COY_EMBARK_PT = random_index(3,5)

    -- target points
    -- for example:
    -- _MACV_GUNSHIPS_TARGET_PT = random_pick({1,2,3,4,5,6,7,8,12})

    -- others ...
    -- for example:
    -- NUMBER_VC_ATTACKS = 0
    -- _2ND_ARVN_MARINE_BTN_LEADERLESS = false
    -- NUMBER_US_AIRSTRIKES = air_support("a")
    -- BATTLE_PLAN_HMONG = dieroll(2)

end

------------------------------------------------------------------------------------------------------------------------

function show_briefing (side) -- DO NOT REMOVE

    -- player briefings

    if side == SIDE_A then

            dialog("SMEAC", 
                   "Battle of 881 North and 881 South\n" ..
                   "\n" ..
                   "\n" .. 
                   "SITUATION:\n" ..
                   "\n" ..
                   "After withdrawing from the mountains, a new plan has been developed to take the hilltops in the area. This time, two battalions will be committed to the operation.\n" ..
                   "\n" ..
                   "Friendly Forces: 2d/3d Marines and 3d/3d Marines, with heavy artillery support.\n" ..
                   "\n" ..
                   "Enemy Forces: The NVA D8/Regiment 18, engaged in the previous fighting, and now grown in force.\n" ..
                   "\n" ..
                   "\n" .. 
                   "MISSION:\n" ..
                   "\n" ..
                   "Your Primary Mission is to take Hill 881 South and Hill 861.\n" ..
                   "\n" ..
                   "Once taken, your Secondary Mission is to capture Hill 881 North and vicinity.\n" ..
                   "\n" ..
                   "Kill as many NVA as possible.\n" ..
                   "\n" ..
                   "\n" .. 
                   "EXECUTION:\n" ..
                   "\n" ..
                   "2d/3d Marines will advance on Hill 861 and the Hill 861 Saddle, while 3d/3d Marines will move to Hill 881 South. Assail both places vigorously.\n" ..
                   "\n" ..
                   "When those areas are secure, attack and capture Hill 881 North, thereafter defending against any counterattack.\n" ..
                   "\n" ..
                   "\n" .. 
                   "POLITICAL:\n" ..
                   "\n" ..
                   "No special political considerations.\n" ..
                   "\n" ..
--                 " You lose Event Points for indirect firing or ordering airstrikes on inhabited hexes (village, city, suburb), whether or not occupied by the enemy.\n\n" ..
                   "\n" ..
                   "ADMIN:\n" ..
                   "\n" ..
                   "Supply levels are high at the beginning of the scenario, but expect them to taper off as the situation unfolds. Supplies will become available once you have secured Hill 881 South and Hill 861.\n" ..
                   "\n" ..
                   "\n" .. 
                   "COMMAND AND CONTROL:\n" ..
                   "\n" ..
                   "Weather will be mostly cloudy, with low hanging clouds. Visibility will lightly vary as the day progresses. Night will fall at Turn 30.\n",
                   side, side
                  )

    elseif side == SIDE_B then

            dialog("Side B Briefing", 
                   "Battle of 881 North and 881 South\n" ..
                   "\n" ..
                   "WARNING: This is currently best played as the SIDE A player unless being played Head to Head. Please restart the scenario as SIDE A.\n" ..
                   "\n" ..
                   "SITUATION:\n" ..
                   "\n" ..
                   "You have successfully defeated and pushed the Imperialists out of the hills. General Giap is most pleased!\n" ..
                   "\n" ..
                   "The Americans are preparing another attack, but we shall stop them once more!\n" ..
                   "\n" ..
                   "Friendly Forces: You have Regiment 18/Division 325 supported by heavy weapons.\n" ..
                   "\n" ..
                   "Enemy Forces: Intelligence reports that elements of the 3rd Marine Regiment are advancing into the hills.\n" ..
                   "\n" ..
                   "\n" .. 
                   "MISSION:\n" ..
                   "\n" ..
                   "Your primary mission is to hold onto the hilltops. Hill 881 North and Hill 881 South are the most important of these.\n" ..
                   "\n" ..
                   "Your secondary mission is to destroy as many American companies as you can!\n" ..
                   "\n" ..
                   "\n" .. 
                   "EXECUTION:\n" ..
                   "\n" ..
                   "Stall the Imperialist advance into the mountains. Counterattack their weak points, retaking any lost hilltops, especially after nightfall.\n" ..
                   "\n" ..
                   "Inflict as many casualties as possible.\n" ..
                   "\n" ..
                   "\n" .. 
                   "POLITICAL:\n" ..
                   "\n" ..
                   "No special political considerations.\n" ..
                   "\n" ..
--                 " You lose Event Points for indirect firing or ordering airstrikes on inhabited hexes (village, city, suburb), whether or not occupied by the enemy.\n\n" ..
                   "\n" ..
                   "ADMIN:\n" ..
                   "\n" ..
                   "Supply levels are high at the beginning of the scenario, but expect them to taper off as the situation unfolds. Upon arrival of your trailporters at Lang Ruon, you will receive additional supplies.\n" ..
                   "\n" ..
                   "\n" .. 
                   "COMMAND AND CONTROL:\n" ..
                   "\n" ..
                   "Weather will be mostly cloudy, with low hanging clouds. Visibility will lightly vary as the day progresses. Night will fall at Turn 30.\n",
                   side, side
                  )

    end

end

------------------------------------------------------------------------------------------------------------------------

function on_shutdown () -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------
    
function on_next_turn (turn) -- DO NOT REMOVE
    

    -- after first (in)direct fire, Side A loses (arty) supply each turn
    if SIDE_A_FIRED then
        inc_ammo_level(SIDE_A, -2)
    end
    if SIDE_A_ARTY_FIRED then
        inc_arty_ammo_level(SIDE_A, -2)
    end

    -- after first (in)direct fire, Side B loses (arty) supply each turn
    if SIDE_B_FIRED then
        inc_ammo_level(SIDE_B, -2)
    end
    if SIDE_B_ARTY_FIRED then
        inc_arty_ammo_level(SIDE_B, -2)
    end
    
    -- Free World Airstrike Management
    if turn == 1 then
        allot_airstrikes(UNKNOWN, US_SIDE, 0, 0, 0)
    end
    if turn == 6 then
        allot_airstrikes(6, US_SIDE, dieroll(4)-1, 4, 30, "", "Some air support is now on station and ready to assist in your operation!")
    elseif turn >= 7 and turn <= 29 then
        allot_airstrikes(UNKNOWN, US_SIDE, random_pick({0,0,1,1,1,1,2,2,3}), 4)
    end
    if turn == 30 then
        allot_airstrikes(UNKNOWN, US_SIDE, 0, 0, 0, "Air support has been halted due to evening weather!", "")
    end

end

------------------------------------------------------------------------------------------------------------------------

function on_next_phase (turn, side) -- DO NOT REMOVE

    -- for testing purposes; note that these might override player selected options!
    -- by default, in normal game play, the player selected options apply;
    -- by default, in auto-test mode, FOW is OFF, all the time, for both sides
    if is_test_trial_play() and not is_qa_testing() then
        set_fow(side, 0) -- for current side, set FOW OFF
        set_fow(other_side(side), 1) -- for opposing side, set FOW ON
    end

    set_org_lists(turn, side)

    if turn == 1 then
        show_briefing(side)
    end

    battle_plan(turn, side)

--[[ commonly used, uncomment and adapt as necessary:
    -- every phase, adjust downward the NVA assault_attack_aggressiveness_effect bonus per their current loss rate
    adjust_adaptive_ai (sideof(NORTH_VIETNAM_NATION), NORTH_VIETNAM_NATION, "assault_attack_aggressiveness_effect", - math.floor(total_loss_rate(sideof(NORTH_VIETNAM_NATION))/2))
--]]

    if side == US_SIDE then

        -- American gain
        -- American gains for securing HILL_861
        if owned(HILL_861, US_SIDE) then
            TURNS_US_HOLD_HILL_861 = (TURNS_US_HOLD_HILL_861 or 0) + 1
            log(LUALOG, LOG_DEBUG, "in on_next_turn(), Turn " .. turn .. ", TURNS_US_HOLD_HILL_861 " .. TURNS_US_HOLD_HILL_861)
            if TURNS_US_HOLD_HILL_861 == 2 then -- not >= 2, to ensure one-time only EP gain
                inc_event_points(US_SIDE, 200)
                dialog("Free World forces clears Hill 861", "For clearing and maintaining all of Hill 861 for 2 turns, the US side gains 200 EPs.", US_SIDE, US_SIDE)
            end
        end  

        -- American gains for securing HILL_861_SADDLE
        if owned(HILL_861_SADDLE, US_SIDE) then
            TURNS_US_HOLD_HILL_861_SADDLE = (TURNS_US_HOLD_HILL_861_SADDLE or 0) + 1
            log(LUALOG, LOG_DEBUG, "in on_next_turn(), Turn " .. turn .. ", TURNS_US_HOLD_HILL_861_SADDLE " .. TURNS_US_HOLD_HILL_861_SADDLE)
            if TURNS_US_HOLD_HILL_861_SADDLE == 2 then -- not >= 2, to ensure one-time only EP gain
                inc_event_points(US_SIDE, 200)
                dialog("Free World forces clears the Hill 861 Saddle", "For clearing and maintaining all of the Hill 861 Saddle for 2 turns, the US side gains 200 EPs.", US_SIDE, US_SIDE)
            end
        end  
        
        -- American gains for securing HILL_881_NORTH
        if owned(HILL_881_NORTH, US_SIDE) then
            TURNS_US_HOLD_HILL_881_NORTH = (TURNS_US_HOLD_HILL_881_NORTH or 0) + 1
            log(LUALOG, LOG_DEBUG, "in on_next_turn(), Turn " .. turn .. ", TURNS_US_HOLD_HILL_881_NORTH " .. TURNS_US_HOLD_HILL_881_NORTH)
            if TURNS_US_HOLD_HILL_881_NORTH == 2 then -- not >= 2, to ensure one-time only EP gain
                inc_event_points(US_SIDE, 300)
                dialog("Free World forces clears Hill 881 North", "For clearing and maintaining all of Hill 881 North for 2 turns, the US side gains 300 EPs.", US_SIDE, US_SIDE)
            end
        end  
        
        -- American gains for securing HILL_881_SOUTH
        if owned(HILL_881_SOUTH, US_SIDE) then
            TURNS_US_HOLD_HILL_881_SOUTH = (TURNS_US_HOLD_HILL_881_SOUTH or 0) + 1
            log(LUALOG, LOG_DEBUG, "in on_next_turn(), Turn " .. turn .. ", TURNS_US_HOLD_HILL_881_SOUTH " .. TURNS_US_HOLD_HILL_881_SOUTH)
            if TURNS_US_HOLD_HILL_881_SOUTH == 2 then -- not >= 2, to ensure one-time only EP gain
                inc_event_points(US_SIDE, 300)
                dialog("Free World forces clears Hill 881 South", "For clearing and maintaining all of Hill 881 South for 2 turns, the US side gains 300 EPs.", US_SIDE, US_SIDE)
            end
        end  

        -- American gains for securing HILL_700
        if owned(HILL_700, US_SIDE) then
            TURNS_US_HOLD_HILL_700 = (TURNS_US_HOLD_HILL_700 or 0) + 1
            log(LUALOG, LOG_DEBUG, "in on_next_turn(), Turn " .. turn .. ", TURNS_US_HOLD_HILL_700 " .. TURNS_US_HOLD_HILL_700)
            if TURNS_US_HOLD_HILL_700 == 2 then -- not >= 2, to ensure one-time only EP gain
                inc_event_points(US_SIDE, 100)
                dialog("Free World forces clears Hill 700", "For clearing and maintaining all of Hill 700 for 2 turns, the US side gains 100 EPs.", US_SIDE, US_SIDE)
            end
        end  

        -- American gains for securing HILL_516
        if owned(HILL_516, US_SIDE) then
            TURNS_US_HOLD_HILL_516 = (TURNS_US_HOLD_HILL_516 or 0) + 1
            log(LUALOG, LOG_DEBUG, "in on_next_turn(), Turn " .. turn .. ", TURNS_US_HOLD_HILL_516 " .. TURNS_US_HOLD_HILL_516)
            if TURNS_US_HOLD_HILL_516 == 2 then -- not >= 2, to ensure one-time only EP gain
                inc_event_points(US_SIDE, 100)
                dialog("Free World forces clears Hill 516", "For clearing and maintaining all of Hill 516 for 2 turns, the US side gains 100 EPs.", US_SIDE, US_SIDE)
            end
        end  

        -- American gains for securing LANG_RUON
        if owned(LANG_RUON, US_SIDE) then
            TURNS_US_HOLD_LANG_RUON = (TURNS_US_HOLD_LANG_RUON or 0) + 1
            log(LUALOG, LOG_DEBUG, "in on_next_turn(), Turn " .. turn .. ", TURNS_US_HOLD_LANG_RUON " .. TURNS_US_HOLD_LANG_RUON)
            if TURNS_US_HOLD_LANG_RUON == 2 then -- not >= 2, to ensure one-time only EP gain
                inc_event_points(US_SIDE, 50)
                dialog("Free World forces clears Lang Ruon", "For clearing and maintaining Lang Ruon for 2 turns, the US side gains 50 EPs.", US_SIDE, US_SIDE)
            end
        end  

        -- American gains for securing XOM_BONG
        if owned(XOM_BONG, US_SIDE) then
            TURNS_US_HOLD_XOM_BONG = (TURNS_US_HOLD_XOM_BONG or 0) + 1
            log(LUALOG, LOG_DEBUG, "in on_next_turn(), Turn " .. turn .. ", TURNS_US_HOLD_XOM_BONG " .. TURNS_US_HOLD_XOM_BONG)
            if TURNS_US_HOLD_XOM_BONG == 2 then -- not >= 2, to ensure one-time only EP gain
                inc_event_points(US_SIDE, 50)
                dialog("Free World forces clears Xom Bong", "For clearing and maintaining Xom Bong for 2 turns, the US side gains 50 EPs.", US_SIDE, US_SIDE)
            end
        end  

    end

    if side == NVA_SIDE then
   
        -- NVA gain 25 EPs for holding HILL_861 every 5 turns
        if turn == 5 or
            turn == 10 or
            turn == 15 or
            turn == 20 or
            turn == 15 or
            turn == 30 or
            turn == 35 or
            turn == 40 then
            if not owned(HILL_861, US_SIDE) then
                inc_event_points(NVA_SIDE, 25)
                dialog("NVA Holding all of Hill 861", "For continuing to hold all of Hill 861, the North Vietnamese side gains 25 EPs.", VC_SIDE, VC_SIDE)
            end
        end  

        -- NVA gain 25 EPs for holding HILL_861_SADDLE every 5 turns
        if turn == 5 or
            turn == 10 or
            turn == 15 or
            turn == 20 or
            turn == 15 or
            turn == 30 or
            turn == 35 or
            turn == 40 then
            if not owned(HILL_861_SADDLE, US_SIDE) then
                inc_event_points(NVA_SIDE, 25)
                dialog("NVA Holding all of the HILL_861_SADDLE", "For continuing to hold all of the Hill 861 Saddle, the North Vietnamese side gains 25 EPs.", VC_SIDE, VC_SIDE)
            end
        end  

        -- NVA gain 50 EPs for holding HILL_881_NORTH every 5 turns
        if turn == 5 or
            turn == 10 or
            turn == 15 or
            turn == 20 or
            turn == 15 or
            turn == 30 or
            turn == 35 or
            turn == 40 then
            if not owned(HILL_881_NORTH, US_SIDE) then
                inc_event_points(NVA_SIDE, 50)
                dialog("NVA Holding all of the HILL_881_NORTH", "For continuing to hold all of Hill 881 North, the North Vietnamese side gains 50 EPs.", VC_SIDE, VC_SIDE)
            end
        end  

        -- NVA gain 50 EPs for holding HILL_881_SOUTH every 5 turns
        if turn == 5 or
            turn == 10 or
            turn == 15 or
            turn == 20 or
            turn == 15 or
            turn == 30 or
            turn == 35 or
            turn == 40 then
            if not owned(HILL_881_SOUTH, US_SIDE) then
                inc_event_points(NVA_SIDE, 50)
                dialog("NVA Holding all of the HILL_881_SOUTH", "For continuing to hold all of Hill 881 South, the North Vietnamese side gains 50 EPs.", VC_SIDE, VC_SIDE)
            end
        end  

        -- NVA gain 20 EPs for holding HILL_700 every 5 turns
        if turn == 5 or
            turn == 10 or
            turn == 15 or
            turn == 20 or
            turn == 15 or
            turn == 30 or
            turn == 35 or
            turn == 40 then
            if not owned(HILL_700, US_SIDE) then
                inc_event_points(NVA_SIDE, 20)
                dialog("NVA Holding all of Hill 700", "For continuing to hold all of Hill 700, the North Vietnamese side gains 20 EPs.", VC_SIDE, VC_SIDE)
            end
        end  

        -- NVA gain 20 EPs for holding HILL_516 every 5 turns
        if turn == 5 or
            turn == 10 or
            turn == 15 or
            turn == 20 or
            turn == 15 or
            turn == 30 or
            turn == 35 or
            turn == 40 then
            if not owned(HILL_516, US_SIDE) then
                inc_event_points(NVA_SIDE, 20)
                dialog("NVA Holding all of Hill 516", "For continuing to hold all of Hill 516, the North Vietnamese side gains 20 EPs.", VC_SIDE, VC_SIDE)
            end
        end  

        -- NVA gain 15 EPs for holding XOM_BONG every 5 turns
        if turn == 5 or
            turn == 10 or
            turn == 15 or
            turn == 20 or
            turn == 15 or
            turn == 30 or
            turn == 35 or
            turn == 40 then
            if not owned(XOM_BONG, US_SIDE) then
                inc_event_points(NVA_SIDE, 15)
                dialog("NVA Holding all of Xom Bong", "For continuing to hold all of Xom Bong, the North Vietnamese side gains 15 EPs.", VC_SIDE, VC_SIDE)
            end
        end  

        -- NVA gain 15 EPs for holding LANG_RUON every 5 turns
        if turn == 5 or
            turn == 10 or
            turn == 15 or
            turn == 20 or
            turn == 15 or
            turn == 30 or
            turn == 35 or
            turn == 40 then
            if not owned(LANG_RUON, US_SIDE) then
                inc_event_points(NVA_SIDE, 15)
                dialog("NVA Holding all of Lang Ruon", "For continuing to hold all of Lang Ruon, the North Vietnamese side gains 15 EPs.", VC_SIDE, VC_SIDE)
            end
        end  

    end

    csee_check(turn, side) -- DO NOT MOVE, OR REMOVE

end

------------------------------------------------------------------------------------------------------------------------

function battle_plan (turn, side)

    -- UNLEASH is true if game launched with -U switch, or if Ctrl+Alt+U in game
    -- Ctrl+Alt+U is a toggle, so will set UNLEASH to false after an earlier Ctrl+Alt+U (setting UNLEASH to true)
    if UNLEASH then
        unleash(ALLA)
        unleash(ALLB)
        return
    end

    if side == SIDE_A and is_ai(side) then

        --traceon()
        battle_plan_a(turn, side)
        --traceoff()

    elseif side == SIDE_B and is_ai(side) then

        --traceon()
        battle_plan_b(turn, side)
        --traceoff()

    end

end

------------------------------------------------------------------------------------------------------------------------

function battle_plan_a (turn, side)


    -- standard orders, uncomment as necessary:
    if turn == 1 then
        -- all Side A units hold initially (or maybe use halt())
        halt(ALLA)
    end


--[[

    ---------------------------------------------------------------------------
    -- _KHE_SANH_COMBAT_BASE_AND_AREA_215 -- Khe Sanh Combat Base - and area --
    ---------------------------------------------------------------------------

    -- _BRG_HQ_216 -- Brigade HQ (foot)
    do local units = _BRG_HQ_216

    end

    -- _M35_521 -- 2 1/2 ton truck armed
    do local units = _M35_521

    end

    ------------------------------------------------------------------
    -- _3RD_MARINE_INF_RGT_67_43 -- 3rd Marine Infantry Regiment 67 --
    ------------------------------------------------------------------

    ---------------------------------------------------------------------------------
    -- _2ND_3RD_MARINE_BTN_66_MARINES_116 -- 2nd/3rd Marine Battalion 66 - MARINES --
    ---------------------------------------------------------------------------------

    -- _BTN_HQ_117 -- Battalion HQ (foot)
    do local units = _BTN_HQ_117

    end

    -- _2ND_3RD_MARINE_118 -- Commander 1
    do local units = _2ND_3RD_MARINE_118

    end

    -- _E_2ND_3RD_MARINE_INF_COY_66_127 -- E/2nd/3rd Marine Infantry Company 66
    do local units = _E_2ND_3RD_MARINE_INF_COY_66_127

    end

    -- _F_2ND_3RD_MARINE_INF_COY_66_134 -- F/2nd/3rd Marine Infantry Company 66
    do local units = _F_2ND_3RD_MARINE_INF_COY_66_134

    end

    -- _G_2ND_3RD_MARINE_INF_COY_66_141 -- G/2nd/3rd Marine Infantry Company 66
    do local units = _G_2ND_3RD_MARINE_INF_COY_66_141

    end

    -- _H_2ND_3RD_MARINE_INF_COY_66_MARINES_0VP_201 -- H/2nd/3rd Marine Infantry Company 66 - MARINES - 0VP
    do local units = _H_2ND_3RD_MARINE_INF_COY_66_MARINES_0VP_201

    end

    ---------------------------------------------------------------------------------
    -- _3RD_3RD_MARINE_BTN_66_MARINES_155 -- 3rd/3rd Marine Battalion 66 - MARINES --
    ---------------------------------------------------------------------------------

    -- _BTN_HQ_156 -- Battalion HQ (foot)
    do local units = _BTN_HQ_156

    end

    -- _3RD_3RD_MARINE_157 -- Commander 1
    do local units = _3RD_3RD_MARINE_157

    end

    -- _HQ_AND_SERVICE_COY_62_MARINE_158 -- Headquarters and Service Company 62 - Marine
    do local units = _HQ_AND_SERVICE_COY_62_MARINE_158

    end

    -- _K_3RD_3RD_MARINE_INF_COY_66_173 -- K/3rd/3rd Marine Infantry Company 66
    do local units = _K_3RD_3RD_MARINE_INF_COY_66_173

    end

    -- _M_3RD_3RD_MARINE_INF_COY_66_MARINES_0VP_208 -- M/3rd/3rd Marine Infantry Company 66 - MARINES - 0VP
    do local units = _M_3RD_3RD_MARINE_INF_COY_66_MARINES_0VP_208

    end

    -- _M_3RD_9TH_MARINE_INF_COY_66_MARINES_0VP_531 -- M/3rd/9th Marine Infantry Company 66 - MARINES - 0VP
    do local units = _M_3RD_9TH_MARINE_INF_COY_66_MARINES_0VP_531

    end

    -- _LOGISTICS_COY_LEVEL_1_62_MARINES_187 -- Logistics Company - Level 1 - 62 - MARINES
    do local units = _LOGISTICS_COY_LEVEL_1_62_MARINES_187

    end

    -- _SUPPLY_TRUCKS_188 -- Supply Trucks (VP)
    do local units = _SUPPLY_TRUCKS_188

    end

    -- _ENGINEER_COY_66_MARINES_2107 -- Engineer Company 66 - MARINES
    do local units = _ENGINEER_COY_66_MARINES_2107

    end

    -- _LOGISTICS_COY_LEVEL_2_62_MARINES_67 -- Logistics Company - Level 2 - 62 - MARINES
    do local units = _LOGISTICS_COY_LEVEL_2_62_MARINES_67

    end

    -- _F_2ND_12TH_FIELD_ARTILLERY_BTY_66_M101_M35_MARINES_0VP_522 -- F/2nd/12th Field Artillery Battery 66 - M101/M35 - MARINES - 0VP
    do local units = _F_2ND_12TH_FIELD_ARTILLERY_BTY_66_M101_M35_MARINES_0VP_522

    end
    -- _M101_105MM_HOWITZERS_523 -- M101 105mm Howitzers
    -- _M114_155MM_HOWITZERS_525 -- M114 155mm Howitzers
    -- _42_INCH_MORTARS_530 -- M30 4.2-inch Mortars

    -- _B_1ST_12TH_FIELD_ARTILLERY_BTY_66_M101_M35_MARINES_0VP_2160 -- B/1st/12th Field Artillery Battery 66 - M101/M35 - MARINES - 0VP
    do local units = _B_1ST_12TH_FIELD_ARTILLERY_BTY_66_M101_M35_MARINES_0VP_2160

    end

    -- _M101_105MM_HOWITZERS_2161 -- M101 105mm Howitzers
    do local units = _M101_105MM_HOWITZERS_2161

    end

    -- _3RD_MARINE_RECONNAISSANCE_COY_66_MARINES_0VP_2156 -- 3rd Marine Reconnaissance Company 66 - MARINES - 0VP
    do local units = _3RD_MARINE_RECONNAISSANCE_COY_66_MARINES_0VP_2156

    end

    -- _3RD_B_1ST_AMPHIBIAN_TRACTOR_BTN_594 -- LVTP-5
    do local units = _3RD_B_1ST_AMPHIBIAN_TRACTOR_BTN_594

    end

    -- _2ND_A_3RD_ANTITANK_BTN_595 -- M50A1 Ontos SPMRR
    do local units = _2ND_A_3RD_ANTITANK_BTN_595

    end

    -- _3RD_B_3RD_RECONNAISSANCE_BTN_596 -- Marine Reconnaissance 65
    do local units = _3RD_B_3RD_RECONNAISSANCE_BTN_596

    end

    -- _3RD_B_3RD_RECONNAISSANCE_BTN_M151_597 -- 1/4 ton truck
    do local units = _3RD_B_3RD_RECONNAISSANCE_BTN_M151_597

    end

    -- _M35A2_M55_SPAA_2123 -- M35A2/M55 SPAA
    do local units = _M35A2_M55_SPAA_2123

    end

    ---------------------------------------------------------------------
    -- _LANG_VIE_SPECIAL_FORCES_CAMP_1 -- Lang Vie Special Forces Camp --
    ---------------------------------------------------------------------

    -- _HQ_2 -- Mike Force Battalion HQ (foot)
    do local units = _HQ_2

    end

    -- _US_ADVISOR_42 -- Commander 2
    do local units = _US_ADVISOR_42

    end

    -- _1ST_MOBILE_STRIKE_FORCE_COY_66_3 -- 1st Mobile Strike Force Company 66
    do local units = _1ST_MOBILE_STRIKE_FORCE_COY_66_3

    end

    -- _CIDG_COY_101_21 -- CIDG Company 101
    do local units = _CIDG_COY_101_21

    end

    -- _CIDG_COY_102_25 -- CIDG Company 102
    do local units = _CIDG_COY_102_25

    end

    -- _1ST_PLT_42_26 -- CIDG Platoon 64
    do local units = _1ST_PLT_42_26

    end

    -- _CIDG_COY_103_29 -- CIDG Company 103
    do local units = _CIDG_COY_103_29

    end

    -- _1ST_PLT_43_30 -- CIDG Platoon 64
    do local units = _1ST_PLT_43_30

    end

    -- _CIDG_COY_104_33 -- CIDG Company 104
    do local units = _CIDG_COY_104_33

    end

    -- _1ST_PLT_44_34 -- CIDG Platoon 64
    do local units = _1ST_PLT_44_34

    end

    -- _SPECIAL_FORCES_TEAM_A101_40 -- Special Forces Team
    do local units = _SPECIAL_FORCES_TEAM_A101_40

    end

    -- _SPECIAL_FORCES_TEAM_A101_41 -- Special Forces Team
    do local units = _SPECIAL_FORCES_TEAM_A101_41

    end

    -- _M1_81MM_MORTARS_3_39 -- M1 81mm Mortars
    do local units = _M1_81MM_MORTARS_3_39

    end

    -- _M40_106MM_RCLR_37 -- CIDG M67 90mm Recoilless Rifle
    do local units = _M40_106MM_RCLR_37

    end

    -- _M2_42_INCH_MORTARS_38 -- M2 4.2-inch Mortars
    do local units = _M2_42_INCH_MORTARS_38

    end

    -----------------------------------------------
    -- _KHE_SANH_VILLAGE_560 -- Khe Sanh Village --
    -----------------------------------------------

    -- _HQ_561 -- ARVN Battalion HQ (foot)
    do local units = _HQ_561

    end

    -- _US_ADVISOR_593 -- Commander 1
    do local units = _US_ADVISOR_593

    end

    -- _COMBINED_ACTION_COY_OSCAR_545 -- Combined Action Company Oscar
    do local units = _COMBINED_ACTION_COY_OSCAR_545

    end

    -- _REGIONAL_FORCE_COY_64_II_0VP_555 -- Regional Force Company 64 - II - 0VP
    do local units = _REGIONAL_FORCE_COY_64_II_0VP_555

    end

    -- _FSB_ROCKPILE_2ND_94TH_538 -- FSB Rockpile - 2nd/94th
    do local units = _FSB_ROCKPILE_2ND_94TH_538

    end

    -----------------------------------------------------------------------------------------------------
    -- _VMO6_MARINE_OBSERVATION_SQUADRON_66_UH1E_2125 -- VMO-6 Marine Observation Squadron  66 - UH-1E --
    -----------------------------------------------------------------------------------------------------

    -- _UH1E_2127 -- UH-1E Gunship Rockets
    do local units = _UH1E_2127

    end

    ----------------------------------------------------------------------------------------------------------------------------------
    -- _HMM_MARINE_MEDIUM_HELICOPTER_SQUADRON_62_UH34_MARINES_2147 -- HMM-# Marine Medium Helicopter Squadron 62  - UH-34 - MARINES --
    ----------------------------------------------------------------------------------------------------------------------------------

    -- _UH34_2150 -- CH-34 Choctaw
    do local units = _UH34_2150

    end

    ----------------------------------------------------------------------------------------------------------------------------------
    -- _HMM_MARINE_MEDIUM_HELICOPTER_SQUADRON_67_CH46_MARINES_2141 -- HMM-# Marine Medium Helicopter Squadron  67 - CH-46 - MARINES --
    ----------------------------------------------------------------------------------------------------------------------------------

    -- _CH46_2143 -- CH-46 Sea Knight
    do local units = _CH46_2143

    end

    -- _VOUGHT_F8_CRUSADER_BOMBS_2165 -- Vought F-8 Crusader {Bombs}
    do local units = _VOUGHT_F8_CRUSADER_BOMBS_2165

    end

    -- _VOUGHT_F8_CRUSADER_BOMBS_2166 -- Vought F-8 Crusader {Bombs}
    do local units = _VOUGHT_F8_CRUSADER_BOMBS_2166

    end

    -- _VOUGHT_F8_CRUSADER_BOMBS_2167 -- Vought F-8 Crusader {Bombs}
    do local units = _VOUGHT_F8_CRUSADER_BOMBS_2167

    end

    -- _VOUGHT_F8_CRUSADER_BOMBS_2168 -- Vought F-8 Crusader {Bombs}
    do local units = _VOUGHT_F8_CRUSADER_BOMBS_2168

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2169 -- USAF McDonnell Douglas F-4E Phantom II {Napalm}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2169

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2170 -- USAF McDonnell Douglas F-4E Phantom II {Napalm}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2170

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2171 -- USAF McDonnell Douglas F-4E Phantom II {Napalm}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2171

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2172 -- USAF McDonnell Douglas F-4E Phantom II {Napalm}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2172

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2173 -- USAF McDonnell Douglas F-4E Phantom II {Napalm}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2173

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2174 -- USAF McDonnell Douglas F-4E Phantom II {Napalm}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2174

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2175 -- USAF McDonnell Douglas F-4E Phantom II {Napalm}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_NAPALM_2175

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2176 -- USAF McDonnell Douglas F-4E Phantom II {Bombs}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2176

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2177 -- USAF McDonnell Douglas F-4E Phantom II {Bombs}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2177

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2178 -- USAF McDonnell Douglas F-4E Phantom II {Bombs}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2178

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2179 -- USAF McDonnell Douglas F-4E Phantom II {Bombs}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2179

    end

    -- _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2180 -- USAF McDonnell Douglas F-4E Phantom II {Bombs}
    do local units = _USAF_MCDONNELL_DOUGLAS_F4E_PHANTOM_II_BOMBS_2180

    end

    -- _VOUGHT_F8_CRUSADER_BOMBS_2181 -- Vought F-8 Crusader {Bombs}
    do local units = _VOUGHT_F8_CRUSADER_BOMBS_2181

    end

    -- _VOUGHT_F8_CRUSADER_BOMBS_2182 -- Vought F-8 Crusader {Bombs}
    do local units = _VOUGHT_F8_CRUSADER_BOMBS_2182

    end

    -- _VOUGHT_F8_CRUSADER_BOMBS_2183 -- Vought F-8 Crusader {Bombs}
    do local units = _VOUGHT_F8_CRUSADER_BOMBS_2183

    end

    -- _VOUGHT_F8_CRUSADER_BOMBS_2184 -- Vought F-8 Crusader {Bombs}
    do local units = _VOUGHT_F8_CRUSADER_BOMBS_2184

    end

    -- _VOUGHT_F8_CRUSADER_BOMBS_2185 -- Vought F-8 Crusader {Bombs}
    do local units = _VOUGHT_F8_CRUSADER_BOMBS_2185

    end

--]]

end

------------------------------------------------------------------------------------------------------------------------

function battle_plan_b (turn, side)


    -- standard orders, uncomment as necessary:
    if turn == 1 then
        -- all Side B units hold initially (or maybe use halt())
        halt(ALLB)
    end


    --------------------------------------------------
    -- _DIV_325_NVA_67_971 -- Division 325 - NVA 67 --
    --------------------------------------------------

    ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
    -- _RGT_18C_NVA_REGULAR_INF_RGT_67_AK_B_SVN_I_CORPS_DIV_325_QUANG_TRI_1290 -- Regiment 18C - NVA Regular Infantry Regiment 67 - AK - B - SVN I Corps/Division 325/Quang Tri --
    ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

    -- _TRUNG_DOAN_HQ_1291 -- NVA Regimental HQ (foot)
    do local units = join({_TRUNG_DOAN_HQ_1291,_R18C_1292})
		defend_normal(units, "43,46", NODIR, 1, 100)
    end

    -- _R18C_1292 -- NVA Commander 2
    do local units = _R18C_1292

    end

    -----------------------------------------------------------------------------------------------
    -- _D7_R18C_NVA_REGULAR_INF_BTN_67_AK_1293 -- D7/R18C NVA Regular Infantry Battalion 67 - AK --
    -----------------------------------------------------------------------------------------------

    -- _TIEU_DOAN_HQ_1294 -- NVA Battalion HQ (foot)
    do local units = join({_TIEU_DOAN_HQ_1294,_D7_R18C_2100})
		defend_normal(units, "48,53", NODIR, 1, 100)
    end

    -- _D7_R18C_2100 -- NVA Commander 1
    do local units = _D7_R18C_2100

    end

    -- _C1_NVA_RIFLE_COY_67_AK_B_SVN_1295 -- C1 NVA Rifle Company 67 - AK - B - SVN
    do local units = difference(_C1_NVA_RIFLE_COY_67_AK_B_SVN_1295,{1296,1301})
		_C1_NVA_RIFLE_COY_67_AK_B_SVN_1295_ATTACK_VECTOR = _C1_NVA_RIFLE_COY_67_AK_B_SVN_1295_ATTACK_VECTOR or random_pick({ATTACK_LEFT, ATTACK_CENTER, ATTACK_RIGHT}) 
		
		if DEBUG then
			log(LUALOG, LOG_DEBUG, "_C1_NVA_RIFLE_COY_67_AK_B_SVN_1295_ATTACK_VECTOR " .. _C1_NVA_RIFLE_COY_67_AK_B_SVN_1295_ATTACK_VECTOR)
		end 
		
		if _C1_NVA_RIFLE_COY_67_AK_B_SVN_1295_ATTACK_VECTOR == ATTACK_LEFT then
			local hex52_53_count = units_within_count("52,53", NODIR, 1, US_SIDE, true)
			if turn >= 29 then
				if (hex52_53_count >= 3) then
					defend_strong(units, "52,53", NODIR, 1, 100)
				elseif (hex52_53_count >= 1) and (hex52_53_count <= 2) then
					attack_nearest_to_hex(units, "52,53", NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (hex52_53_count == 0) and owned(OBJECTIVES[10], US_SIDE) then
					attack_strong(units, OBJECTIVES[10], NODIR, 1, 100)
				elseif (hex52_53_count == 0) and owned(OBJECTIVES[12], US_SIDE) then
					attack_strong(units, OBJECTIVES[12], NODIR, 1, 100)
				else
					defend_strong(units, OBJECTIVES[10], NODIR, 1, 100)
				end
			else
				local hex50_53_count = units_within_count("50,53", NODIR, 1, US_SIDE, true)
				local hex52_53_count = units_within_count("52,53", NODIR, 1, US_SIDE, true)
				if (hex52_53_count >= 4) then
					defend_strong(units, "50,53", NODIR, 1, 100)
				elseif (hex52_53_count == 3) then
					defend_strong(units, "52,53", NODIR, 1, 100)
				elseif (hex52_53_count >= 1) and (hex52_53_count <= 2) then
					attack_nearest_to_hex(units, "52,53", NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (hex50_53_count >= 3) then
					defend_strong(units, OBJECTIVES[4], NODIR, 1, 100)
				else
					defend_strong(units, "50,53", NODIR, 1, 100)
				end
			end
		elseif _C1_NVA_RIFLE_COY_67_AK_B_SVN_1295_ATTACK_VECTOR == ATTACK_CENTER then
			local hex50_53_count = units_within_count("50,53", NODIR, 1, US_SIDE, true)
			local hex52_53_count = units_within_count("52,53", NODIR, 1, US_SIDE, true)
			if (hex52_53_count >= 4) then
				defend_strong(units, "50,53", NODIR, 1, 100)
			elseif (hex52_53_count == 3) then
				defend_strong(units, "52,53", NODIR, 1, 100)
			elseif (hex52_53_count >= 1) and (hex52_53_count <= 2) then
				attack_nearest_to_hex(units, "52,53", NODIR, 1, 100, ATTACK_STRONG, true)
			elseif (hex50_53_count >= 3) then
				defend_strong(units, OBJECTIVES[4], NODIR, 1, 100)
			else
				defend_strong(units, "50,53", NODIR, 1, 100)
			end			
		elseif _C1_NVA_RIFLE_COY_67_AK_B_SVN_1295_ATTACK_VECTOR == ATTACK_RIGHT then
			local hex52_53_count = units_within_count("52,53", NODIR, 1, US_SIDE, true)
			if turn >= 29 then
				if (hex52_53_count >= 3) then
					defend_strong(units, "52,53", NODIR, 1, 100)
				elseif (hex52_53_count >= 1) and (hex52_53_count <= 2) then
					attack_nearest_to_hex(units, "52,53", NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (hex52_53_count == 0) and owned(OBJECTIVES[13], US_SIDE) then
					attack_strong(units, OBJECTIVES[13], NODIR, 1, 100)
				elseif (hex52_53_count == 0) and owned(OBJECTIVES[12], US_SIDE) then
					attack_strong(units, OBJECTIVES[12], NODIR, 1, 100)
				else
					defend_strong(units, OBJECTIVES[13], NODIR, 1, 100)
				end
			else
				local hex50_53_count = units_within_count("50,53", NODIR, 1, US_SIDE, true)
				local hex52_53_count = units_within_count("52,53", NODIR, 1, US_SIDE, true)
				if (hex52_53_count >= 4) then
					defend_strong(units, "50,53", NODIR, 1, 100)
				elseif (hex52_53_count == 3) then
					defend_strong(units, "52,53", NODIR, 1, 100)
				elseif (hex52_53_count >= 1) and (hex52_53_count <= 2) then
					attack_nearest_to_hex(units, "52,53", NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (hex50_53_count >= 3) then
					defend_strong(units, OBJECTIVES[4], NODIR, 1, 100)
				else
					defend_strong(units, "50,53", NODIR, 1, 100)
				end
			end
		end
    end
    do local units = difference(_C1_NVA_RIFLE_COY_67_AK_B_SVN_1295,{1297,1298,1301})
		local ob4_count = units_within_count(OBJECTIVES[4], NODIR, 1, US_SIDE, true)
		if turn >= 21 then
			if (ob4_count >= 3) then
				defend_strong(units, OBJECTIVES[4], NODIR, 1, 100)
			elseif (ob4_count >= 1) and (ob4_count <= 2) then
				attack_nearest_to_hex(units, OBJECTIVES[4], NODIR, 1, 100, ATTACK_STRONG, true)
			else
				defend_strong(units, "50,53", NODIR, 1, 100)
			end
		elseif turn >= 10 and turn <= 20 then
			local hex52_53_count = units_within_count("52,53", NODIR, 1, US_SIDE, true)
			local hex50_53_count = units_within_count("50,53", NODIR, 1, US_SIDE, true)
			if (hex52_53_count >= 4) then
				defend_strong(units, "50,53", NODIR, 1, 100)
			elseif (hex52_53_count >= 2) and (hex52_53_count <= 3) then
				defend_strong(units, "52,53", NODIR, 1, 100)
			elseif (hex52_53_count == 1) then
				attack_nearest_to_hex(units, "52,53", NODIR, 1, 100, ATTACK_STRONG, true)
			elseif (hex50_53_count >= 3) then
				defend_strong(units, "49,54", NODIR, 1, 100)
			else
				defend_strong(units, "50,53", NODIR, 1, 100)
			end
		else
			defend_strong(units, "50,53", NODIR, 1, 100)
		end
    end
    
    do local units = _FIRE_SUPPORT_MMG_1301
		local hex50_53_count = units_within_count("50,53", NODIR, 1, US_SIDE, true)
		local hex52_53_count = units_within_count("52,53", NODIR, 1, US_SIDE, true)
		if (hex52_53_count >= 3) then
			move_rush(units, "50,53")
		else
			fire_direct_nearest_to_hex(units, "52,53", 100, true)
		end
		if at(units, "50,53") then 
			if (hex50_53_count >= 4) then
				move_rush(units, "48,54")
			else
				fire_direct_nearest_to_hex(units, "50,53", 100, true)
			end
		end
		if at(units, "48,54") then 
			fire_direct_nearest_to_hex(units, "48,54", 100, true)
		end
    end
    
    -- _C2_NVA_RIFLE_COY_67_AK_B_SVN_1302 -- C2 NVA Rifle Company 67 - AK - B - SVN
    do local units = difference(_C2_NVA_RIFLE_COY_67_AK_B_SVN_1302,{1308})
		local ob4_count = units_within_count(OBJECTIVES[4], NODIR, 1, US_SIDE, true)
		local ob5_count = units_within_count(OBJECTIVES[5], NODIR, 1, US_SIDE, true)
		local ob7_count = units_within_count(OBJECTIVES[7], NODIR, 1, US_SIDE, true)
		if turn >= 29 then
			if (ob4_count == 0) and owned(OBJECTIVES[5], US_SIDE) then
				attack_strong(units, OBJECTIVES[5], NODIR, 0, 100)
			elseif (ob4_count == 0) and owned(OBJECTIVES[7], US_SIDE) then
				attack_strong(units, OBJECTIVES[7], NODIR, 0, 100)
			elseif (ob4_count == 0) and ((ob7_count >= 1) and (ob7_count <= 3)) then
				attack_nearest_to_hex(units, OBJECTIVES[7], NODIR, 1, 100, ATTACK_STRONG, true)
			elseif (ob4_count == 0) and ((ob5_count >= 1) and (ob5_count <= 3)) then
				attack_nearest_to_hex(units, OBJECTIVES[5], NODIR, 1, 100, ATTACK_STRONG, true)
			else
				defend_strong(units, OBJECTIVES[4], NODIR, 1, 100)
			end
		else
			if (ob4_count >= 3) then 
				defend_strong(units, OBJECTIVES[4], NODIR, 1, 100)
			elseif ((ob4_count >= 1) and (ob4_count <= 2)) then
				attack_nearest_to_hex(units, OBJECTIVES[4], NODIR, 1, 100, ATTACK_STRONG, true)
			else
				defend_normal(units, OBJECTIVES[4], NODIR, 1, 100)
			end
		end
    end
    do local units = _FIRE_SUPPORT_MMG_1308
		local ob4_count = units_within_count(OBJECTIVES[4], NODIR, 1, US_SIDE, true)
		if (ob4_count >= 5) then 
			move_rush(units, "45,52")
		else
			fire_direct_nearest_to_hex(units, OBJECTIVES[4], 100, true)
		end
		if at(units, "45,52") then 
			if (ob4_count >= 4) then 
				move_rush(units, OBJECTIVES[1])
			else
				fire_direct_nearest_to_hex(units, "45,52", 100, true)
			end
		end
		if at(units, OBJECTIVES[1]) then 
			fire_direct_nearest_to_hex(units, OBJECTIVES[1], 100, true)
		end
    end
    
    -- _C3_NVA_RIFLE_COY_67_AK_B_SVN_1309 -- C3 NVA Rifle Company 67 - AK - B - SVN
    do local units = difference(_C3_NVA_RIFLE_COY_67_AK_B_SVN_1309,{1315})
		_C3_NVA_RIFLE_COY_67_AK_B_SVN_1309_ATTACK_VECTOR = _C3_NVA_RIFLE_COY_67_AK_B_SVN_1309_ATTACK_VECTOR or random_pick({ATTACK_LEFT, ATTACK_CENTER, ATTACK_RIGHT}) 
		
		if DEBUG then
			log(LUALOG, LOG_DEBUG, "_C3_NVA_RIFLE_COY_67_AK_B_SVN_1309_ATTACK_VECTOR " .. _C3_NVA_RIFLE_COY_67_AK_B_SVN_1309_ATTACK_VECTOR)
		end 
		if _C3_NVA_RIFLE_COY_67_AK_B_SVN_1309_ATTACK_VECTOR == ATTACK_LEFT then
			local ob2_count = units_within_count(OBJECTIVES[2], NODIR, 1, US_SIDE, true)
			local ob3_count = units_within_count(OBJECTIVES[3], NODIR, 1, US_SIDE, true)
			local ob6_count = units_within_count(OBJECTIVES[6], NODIR, 1, US_SIDE, true)
			if turn >= 29 then
				if (ob2_count >= 3) then
					defend_strong(units, OBJECTIVES[2], NODIR, 1, 100)
				elseif (ob2_count >= 1) and (ob2_count <= 2) then
					attack_nearest_to_hex(units, OBJECTIVES[2], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob2_count == 0) and ((ob3_count >= 1) and (ob3_count <= 2)) then
					attack_nearest_to_hex(units, OBJECTIVES[6], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob2_count == 0) and owned(OBJECTIVES[3], US_SIDE) then
					attack_strong(units, OBJECTIVES[3], NODIR, 1, 100)
				elseif (ob2_count == 0) and owned(OBJECTIVES[6], US_SIDE) then
					attack_strong(units, OBJECTIVES[6], NODIR, 1, 100)
				elseif (ob2_count == 0) and ((ob6_count >= 1) and (ob6_count <= 2)) then
					attack_nearest_to_hex(units, OBJECTIVES[6], NODIR, 1, 100, ATTACK_STRONG, true)
				else
					defend_strong(units, OBJECTIVES[3], NODIR, 1, 100)
				end
			else
				local ob4_count = units_within_count(OBJECTIVES[4], NODIR, 1, US_SIDE, true)
				local ob5_count = units_within_count(OBJECTIVES[5], NODIR, 1, US_SIDE, true)
				local ob7_count = units_within_count(OBJECTIVES[7], NODIR, 1, US_SIDE, true)
				if (ob5_count >= 4) then
					defend_strong(units, "50,50", NODIR, 1, 100)
				elseif (ob5_count == 0) and owned(OBJECTIVES[4], US_SIDE) then
					attack_strong(units, OBJECTIVES[4], NODIR, 1, 100)
				elseif (ob5_count >= 1) and (ob5_count <= 3) then
					attack_nearest_to_hex(units, OBJECTIVES[5], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob7_count >= 1) and (ob7_count <= 3) then
					attack_nearest_to_hex(units, OBJECTIVES[7], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob4_count >= 1) and (ob4_count <= 3) then
					attack_nearest_to_hex(units, OBJECTIVES[4], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif owned(OBJECTIVES[5], US_SIDE) then
					attack_strong(units, OBJECTIVES[5], NODIR, 1, 100)
				elseif (ob5_count == 0) and owned(OBJECTIVES[7], US_SIDE) then
					attack_strong(units, OBJECTIVES[7], NODIR, 1, 100)
				elseif owned({OBJECTIVES[4],OBJECTIVES[5],OBJECTIVES[7]}, US_SIDE) then
					defend_strong(units, OBJECTIVES[1], NODIR, 1, 100)
				else
					defend_strong(units)
				end
			end
		elseif _C3_NVA_RIFLE_COY_67_AK_B_SVN_1309_ATTACK_VECTOR == ATTACK_CENTER then
			local ob2_count = units_within_count(OBJECTIVES[2], NODIR, 1, US_SIDE, true)
			local ob3_count = units_within_count(OBJECTIVES[3], NODIR, 1, US_SIDE, true)
			local ob6_count = units_within_count(OBJECTIVES[6], NODIR, 1, US_SIDE, true)
			if turn >= 29 then
				if (ob2_count >= 3) then
					defend_strong(units, OBJECTIVES[2], NODIR, 1, 100)
				elseif (ob2_count >= 1) and (ob2_count <= 2) then
					attack_nearest_to_hex(units, OBJECTIVES[2], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob2_count == 0) and ((ob3_count >= 1) and (ob3_count <= 2)) then
					attack_nearest_to_hex(units, OBJECTIVES[6], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob2_count == 0) and owned(OBJECTIVES[3], US_SIDE) then
					attack_strong(units, OBJECTIVES[3], NODIR, 1, 100)
				elseif (ob2_count == 0) and owned(OBJECTIVES[6], US_SIDE) then
					attack_strong(units, OBJECTIVES[6], NODIR, 1, 100)
				elseif (ob2_count == 0) and ((ob6_count >= 1) and (ob6_count <= 2)) then
					attack_nearest_to_hex(units, OBJECTIVES[6], NODIR, 1, 100, ATTACK_STRONG, true)
				else
					defend_strong(units, OBJECTIVES[3], NODIR, 1, 100)
				end
			else
				local hex50_50_count = units_within_count("50,50", NODIR, 1, US_SIDE, true)
				local ob5_count = units_within_count(OBJECTIVES[5], NODIR, 1, US_SIDE, true)
				local ob7_count = units_within_count(OBJECTIVES[7], NODIR, 1, US_SIDE, true)
				local ob9_count = units_within_count(OBJECTIVES[9], NODIR, 1, US_SIDE, true)
				if (ob5_count >= 4) then
					defend_strong(units, "50,50", NODIR, 1, 100)
				elseif (hex50_50_count == 0) and ((ob5_count >= 1) and (ob5_count <= 3)) then
					attack_strong(units, OBJECTIVES[5], NODIR, 1, 100)
				elseif (hex50_50_count == 0) and ((ob7_count >= 1) and (ob7_count <= 3)) then
					attack_nearest_to_hex(units, OBJECTIVES[7], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob5_count == 0) and owned(OBJECTIVES[7], US_SIDE) then
					attack_strong(units, OBJECTIVES[7], NODIR, 1, 100)
				elseif (hex50_50_count == 0) and ((ob9_count >= 1) and (ob9_count <= 3)) then
					attack_nearest_to_hex(units, OBJECTIVES[9], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob5_count == 0) and owned(OBJECTIVES[9], US_SIDE) then
					attack_strong(units, OBJECTIVES[9], NODIR, 1, 100)
				elseif owned({OBJECTIVES[4],OBJECTIVES[5],OBJECTIVES[7]}, US_SIDE) then
					defend_strong(units, OBJECTIVES[1], NODIR, 1, 100)
				else
					defend_strong(units)
				end
			end
		elseif _C3_NVA_RIFLE_COY_67_AK_B_SVN_1309_ATTACK_VECTOR == ATTACK_RIGHT then
			local ob2_count = units_within_count(OBJECTIVES[2], NODIR, 1, US_SIDE, true)
			local ob3_count = units_within_count(OBJECTIVES[3], NODIR, 1, US_SIDE, true)
			local ob6_count = units_within_count(OBJECTIVES[6], NODIR, 1, US_SIDE, true)
			if turn >= 29 then
				if (ob2_count >= 3) then
					defend_strong(units, OBJECTIVES[2], NODIR, 1, 100)
				elseif (ob2_count >= 1) and (ob2_count <= 2) then
					attack_nearest_to_hex(units, OBJECTIVES[2], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob2_count == 0) and ((ob3_count >= 1) and (ob3_count <= 2)) then
					attack_nearest_to_hex(units, OBJECTIVES[6], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob2_count == 0) and owned(OBJECTIVES[3], US_SIDE) then
					attack_strong(units, OBJECTIVES[3], NODIR, 1, 100)
				elseif (ob2_count == 0) and owned(OBJECTIVES[6], US_SIDE) then
					attack_strong(units, OBJECTIVES[6], NODIR, 1, 100)
				elseif (ob2_count == 0) and ((ob6_count >= 1) and (ob6_count <= 2)) then
					attack_nearest_to_hex(units, OBJECTIVES[6], NODIR, 1, 100, ATTACK_STRONG, true)
				else
					defend_strong(units, OBJECTIVES[3], NODIR, 1, 100)
				end				
			else
				local hex50_50_count = units_within_count("50,50", NODIR, 1, US_SIDE, true)
				local ob5_count = units_within_count(OBJECTIVES[5], NODIR, 1, US_SIDE, true)
				local ob7_count = units_within_count(OBJECTIVES[7], NODIR, 1, US_SIDE, true)
				local ob10_count = units_within_count(OBJECTIVES[10], NODIR, 1, US_SIDE, true)
				if (ob5_count >= 4) then
					defend_strong(units, "50,50", NODIR, 1, 100)
				elseif (hex50_50_count == 0) and ((ob5_count >= 1) and (ob5_count <= 3)) then
					attack_strong(units, OBJECTIVES[5], NODIR, 1, 100)
				elseif (hex50_50_count == 0) and ((ob7_count >= 1) and (ob7_count <= 3)) then
					attack_nearest_to_hex(units, OBJECTIVES[7], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob5_count == 0) and owned(OBJECTIVES[7], US_SIDE) then
					attack_strong(units, OBJECTIVES[7], NODIR, 1, 100)
				elseif (hex50_50_count == 0) and ((ob10_count >= 1) and (ob10_count <= 3)) then
					attack_nearest_to_hex(units, OBJECTIVES[10], NODIR, 1, 100, ATTACK_STRONG, true)
				elseif (ob5_count == 0) and owned(OBJECTIVES[10], US_SIDE) then
					attack_strong(units, OBJECTIVES[10], NODIR, 1, 100)
				elseif owned({OBJECTIVES[4],OBJECTIVES[5],OBJECTIVES[7]}, US_SIDE) then
					defend_strong(units, OBJECTIVES[1], NODIR, 1, 100)
				else
					defend_strong(units)
				end	
			end
		end
    end
    do local units = _FIRE_SUPPORT_MMG_1315
		local hex50_50_count = units_within_count("50,50", NODIR, 1, US_SIDE, true)
		local ob7_count = units_within_count(OBJECTIVES[7], NODIR, 1, US_SIDE, true)
		if (ob7_count >= 4) then 
			move_rush(units, "50,50")
		else
			fire_direct_nearest_to_hex(units, OBJECTIVES[7], 100, true)
		end
		if at(units, "50,50") then 
			if (hex50_50_count >= 4) then 
				move_rush(units, OBJECTIVES[3])
			else
				fire_direct_nearest_to_hex(units, "50,50", 100, true)
			end
		end
		if at(units, OBJECTIVES[3]) then 
			fire_direct_nearest_to_hex(units, OBJECTIVES[3], 100, true)
		end
    end
    
    -- _C4_NVA_FIRE_SUPPORT_COY_64_SVN_1316 -- C4 NVA Fire Support Company 64 - SVN
    -- _82MM_MORTARS_1317 -- 82mm Mortars
    do local units = _82MM_MORTARS_1317
		local ob1_count = units_within_count(OBJECTIVES[1], NODIR, 3, US_SIDE, true)
		local ob2_count = units_within_count(OBJECTIVES[2], NODIR, 2, US_SIDE, true)
		local ob3_count = units_within_count(OBJECTIVES[3], NODIR, 1, US_SIDE, true)
		local ob4_count = units_within_count(OBJECTIVES[4], NODIR, 3, US_SIDE, true)
		if (ob1_count >= 1) then 
			fire_indirect_nearest_to_hex(units, OBJECTIVES[1], 100, true)
		elseif (ob2_count >= 1) then 
			fire_indirect_nearest_to_hex(units, OBJECTIVES[1], 100, true)	
		elseif (ob3_count >= 1) then 
			fire_indirect_nearest_to_hex(units, OBJECTIVES[1], 100, true)
		elseif (ob4_count >= 1) then 
			fire_indirect_nearest_to_hex(units, OBJECTIVES[1], 100, true)
		else
			fire_indirect_nearest_to_hex(units, "45,49", 100, true)
		end
    end
    -- _75MM_RCLR_1318 -- NVA RCLR
    do local units = _NVA_HMG_1319
		fire_direct_nearest_to_hex(units, "50,52", 100, true)
    end     
    -- _NVA_HMG_1319 -- NVA HMG
    do local units = _NVA_HMG_1319
		fire_direct_nearest_to_hex(units, "50,52", 100, true)
    end 
    -- _SNIPER_1320 -- NVA Sniper
    do local units = _SNIPER_1320
		fire_direct_nearest_to_hex(units, "49,56", 100, true)
    end
    -- _SNIPER_1321 -- NVA Sniper
    do local units = _SNIPER_1321
		fire_direct_nearest_to_hex(units, "45,52", 100, true)
    end
    -- _SNIPER_1322 -- NVA Sniper
    do local units = _SNIPER_1322
		fire_direct_nearest_to_hex(units, "50,50", 100, true)
    end
    

    -- _DAC_CONG_1332 -- NVA Sapper Platoon 63
    do local units = _DAC_CONG_1332
-- see recce company, it is attached
    end

    -- _THAM_BAO_1333 -- NVA Reconnaissane Platoon 67
    do local units = _THAM_BAO_1333
		local ob1_count = units_within_count(OBJECTIVES[1], NODIR, 3, US_SIDE, true)
		if at(units, "47,47") then
			if (ob1_count >= 2) then
				move_rush(units, OBJECTIVES[1])
			else
				defend_strong(units, "47,47", NODIR, 0, 100)
			end
		end
		if at(units, OBJECTIVES[1]) then
			defend_strong(units, OBJECTIVES[1], NODIR, 0, 100)
		else
			attack_strong(units, OBJECTIVES[1], NODIR, 0, 100)
		end
    end

    -- _SNIPER_1334 -- NVA Sniper
    do local units = _SNIPER_1334
		fire_direct_nearest_to_hex(units, "47,47", 100, true)
    end

    -----------------------------------------------------------------------------------------------
    -- _D8_R18C_NVA_REGULAR_INF_BTN_67_AK_1335 -- D8/R18C NVA Regular Infantry Battalion 67 - AK --
    -----------------------------------------------------------------------------------------------

    -- _TIEU_DOAN_HQ_1336 -- NVA Battalion HQ (foot)
    do local units = join({_TIEU_DOAN_HQ_1336,_D8_R18C_2105})
		defend_normal(units, "45,45", NODIR, 1, 100)
    end

    -- _D8_R18C_2105 -- NVA Commander 2
    do local units = _D8_R18C_2105

    end

    -- _C1_NVA_RIFLE_COY_67_AK_B_SVN_1337 -- C1 NVA Rifle Company 67 - AK - B - SVN
    do local units = difference(_C1_NVA_RIFLE_COY_67_AK_B_SVN_1337,{1343})
		local hex51_45_count = units_within_count("51,45", NODIR, 1, US_SIDE, true)
		local hex54_45_count = units_within_count("54,45", NODIR, 1, US_SIDE, true)
		local ob6_count = units_within_count(OBJECTIVES[6], NODIR, 1, US_SIDE, true)
		local ob8_count = units_within_count(OBJECTIVES[8], NODIR, 1, US_SIDE, true)
		local ob11_count = units_within_count(OBJECTIVES[11], NODIR, 1, US_SIDE, true)
		if (ob11_count >= 4) then
			move_rush(units, "51,57")
		elseif (ob6_count == 0) and ((ob11_count >= 1) and (ob11_count <= 3)) then
			attack_strong(units, OBJECTIVES[11], NODIR, 1, 100)
		elseif (ob6_count == 0) and ((ob8_count >= 1) and (ob8_count <= 3)) then
			attack_nearest_to_hex(units, OBJECTIVES[8], NODIR, 1, 100, ATTACK_STRONG, true)
		elseif (ob6_count == 0) and owned(OBJECTIVES[8], US_SIDE) then
			attack_strong(units, OBJECTIVES[8], NODIR, 1, 100)
		elseif (ob6_count == 0) and owned(OBJECTIVES[11], US_SIDE) then
			attack_strong(units, OBJECTIVES[11], NODIR, 1, 100)
		elseif (ob6_count == 0) and ((hex51_45_count >= 1) and (hex51_45_count <= 3)) then
			attack_nearest_to_hex(units, "51,45", NODIR, 1, 100, ATTACK_STRONG, true)
		elseif (ob6_count == 0) and ((hex54_45_count >= 1) and (hex54_45_count <= 3)) then
			attack_nearest_to_hex(units, "54,45", NODIR, 1, 100, ATTACK_STRONG, true)
		elseif owned(OBJECTIVES[6], US_SIDE) then
			attack_strong(units, OBJECTIVES[6], NODIR, 1, 100)
		else
			defend_strong(units)
		end
		if within(units, "51,57", NODIR, 1) then
			local hex51_47_count = units_within_count("51,47", NODIR, 1, US_SIDE, true)
			local hex51_45_count = units_within_count("51,45", NODIR, 1, US_SIDE, true)
			local hex54_45_count = units_within_count("54,45", NODIR, 1, US_SIDE, true)
			local ob6_count = units_within_count(OBJECTIVES[6], NODIR, 1, US_SIDE, true)
			if (hex51_47_count == 0) and ((ob6_count >= 1) and (ob6_count <= 3)) then
				attack_strong(units, OBJECTIVES[6], NODIR, 1, 100)
			elseif owned(OBJECTIVES[6], US_SIDE) then
				attack_strong(units, OBJECTIVES[6], NODIR, 1, 100)
			elseif (ob6_count == 0) and ((hex51_45_count >= 1) and (hex51_45_count <= 3)) then
				attack_nearest_to_hex(units, "51,45", NODIR, 1, 100, ATTACK_STRONG, true)
			elseif (ob6_count == 0) and ((hex54_45_count >= 1) and (hex54_45_count <= 3)) then
				attack_nearest_to_hex(units, "54,45", NODIR, 1, 100, ATTACK_STRONG, true)
			else
				defend_strong(units, "51,57", NODIR, 1, 100)
			end
		end
    end
    do local units = _FIRE_SUPPORT_MMG_1343
		local hex51_45_count = units_within_count("51,45", NODIR, 1, US_SIDE, true)
		local hex54_48_count = units_within_count("54,48", NODIR, 1, US_SIDE, true)
		if (hex54_48_count >= 3) then
			move_rush(units, "51,45")
		else
			fire_direct_nearest_to_hex(units, "54,49", 100, true)
		end
		if at(units,"51,45") then
			if (hex51_45_count >= 3) then
				move_rush(units, "45,45")
			else
				fire_direct_nearest_to_hex(units, "51,45", 100, true)
			end
		end
		if at(units,"45,45") then
			fire_direct_nearest_to_hex(units, "45,45", 100, true)
		end
    end
    -- _C2_NVA_RIFLE_COY_67_AK_B_SVN_1344 -- C2 NVA Rifle Company 67 - AK - B - SVN
    do local units = difference(_C2_NVA_RIFLE_COY_67_AK_B_SVN_1344,{1350})
		local hex54_49_count = units_within_count("54,49", NODIR, 1, US_SIDE, true)
		local ob9_count = units_within_count(OBJECTIVES[9], NODIR, 1, US_SIDE, true)
		if (hex54_49_count >= 4) then
			defend_strong(units, OBJECTIVES[9], NODIR, 1, 100)
		elseif owned(OBJECTIVES[9], US_SIDE) then
			attack_strong(units, OBJECTIVES[9], NODIR, 1, 100)
		elseif (ob9_count == 0) and ((hex54_49_count >= 1) and (hex54_49_count <= 3)) then
			attack_nearest_to_hex(units, "54,49", NODIR, 1, 100, ATTACK_STRONG, true)
		else
			defend_strong(units)
		end
    end
    do local units = _FIRE_SUPPORT_MMG_1350
		local hex54_49_count = units_within_count("54,49", NODIR, 1, US_SIDE, true)
		if (hex54_49_count >= 3) then
			move_rush(units, OBJECTIVES[9])
		else
			fire_direct_nearest_to_hex(units, "54,49", 100, true)
		end
		if at(units, OBJECTIVES[9]) then
			fire_direct_nearest_to_hex(units, OBJECTIVES[9], 100, true)
		end
    end

    -- _C3_NVA_RIFLE_COY_67_AK_B_SVN_1351 -- C3 NVA Rifle Company 67 - AK - B - SVN
    do local units = difference(_C3_NVA_RIFLE_COY_67_AK_B_SVN_1351,{1357})
		local ob2_count = units_within_count(OBJECTIVES[2], NODIR, 1, US_SIDE, true)
		local ob3_count = units_within_count(OBJECTIVES[3], NODIR, 1, US_SIDE, true)
		if (ob2_count >= 4) then
			defend_strong(units, OBJECTIVES[2], NODIR, 1, 100)
		elseif ((ob2_count >= 1) and (ob2_count <= 3)) then
			attack_nearest_to_hex(units, OBJECTIVES[2], NODIR, 1, 100, ATTACK_STRONG, true)
		elseif owned(OBJECTIVES[3], US_SIDE) then
			attack_strong(units, OBJECTIVES[3], NODIR, 1, 100)
		elseif (ob2_count == 0) and ((ob3_count >= 1) and (ob3_count <= 3)) then
			attack_nearest_to_hex(units, OBJECTIVES[3], NODIR, 1, 100, ATTACK_STRONG, true)
		else
			defend_strong(units)
		end
    end
    do local units = _FIRE_SUPPORT_MMG_1357
		fire_direct_nearest_to_hex(units, OBJECTIVES[2], 100, true)
    end 
    
    -- _C4_NVA_FIRE_SUPPORT_COY_64_SVN_1358 -- C4 NVA Fire Support Company 64 - SVN
    -- _82MM_MORTARS_1359 -- 82mm Mortars
    do local units = _82MM_MORTARS_1359
		local ob2_count = units_within_count(OBJECTIVES[2], NODIR, 3, US_SIDE, true)
		if (ob2_count >= 1) then
			fire_indirect_nearest_to_hex(units, OBJECTIVES[2], 100, true)
		else
			fire_indirect_nearest_to_hex(units, "46,45", 100, true)
		end
    end
    -- _75MM_RCLR_1360 -- NVA RCLR
    do local units = _75MM_RCLR_1360
		fire_direct_nearest_to_hex(units, OBJECTIVES[3], 100, true)
    end     
    -- _NVA_HMG_1361 -- NVA HMG
    do local units = _NVA_HMG_1361
		fire_direct_nearest_to_hex(units, "56,50", 100, true)
    end 
    -- _SNIPER_1362 -- NVA Sniper
    do local units = _SNIPER_1362
		fire_direct_nearest_to_hex(units, "54,51", 100, true)
    end
    -- _SNIPER_1363 -- NVA Sniper
    do local units = _SNIPER_1363
		fire_direct_nearest_to_hex(units, "47,45", 100, true)
    end
    -- _SNIPER_1364 -- NVA Sniper
    do local units = _SNIPER_1364
		fire_direct_nearest_to_hex(units, "51,45", 100, true)
    end


    -- _DAC_CONG_1374 -- NVA Sapper Platoon 63
    do local units = _DAC_CONG_1374
    	defend_strong(units, OBJECTIVES[6], NODIR, 0, 100)
    end

    -- _THAM_BAO_1375 -- NVA Reconnaissane Platoon 67
    do local units = _THAM_BAO_1375
		local ob6_count = units_within_count(OBJECTIVES[6], NODIR, 1, US_SIDE, true)
		local ob9_count = units_within_count(OBJECTIVES[9], NODIR, 1, US_SIDE, true)
		if turn >= 29 then
			if owned(OBJECTIVES[8], US_SIDE) then
    			move_fire_way_point(units, {"48,44","49,42","51,42"}, NODIR, 1, 100)
    		else
    		    move_fire_way_point(units, {"48,44","49,42",OBJECTIVES[8],"54,44"}, NODIR, 1, 100)   
    		end
    		if within(units,"51,42", NODIR, 1) then
    			if owned(OBJECTIVES[8], US_SIDE) then
    				attack_strong(units, OBJECTIVES[8], NODIR, 0, 100)
    			else
					defend_strong(units, "51,42", NODIR, 1, 100)
    			end
    		end
    		if within(units,"54,44", NODIR, 1) then
    			if owned(OBJECTIVES[11], US_SIDE) then
    				attack_strong(units, OBJECTIVES[11], NODIR, 0, 100)
    			else
					defend_strong(units, "54,44", NODIR, 1, 100)
    			end
    		end
		elseif turn >= 10 and turn <= 28 then
			if (ob9_count >= 4) then
				move_rush(units, OBJECTIVES[6])
			else
				defend_strong(units, OBJECTIVES[9], NODIR, 1, 100)
			end
			if within(units, OBJECTIVES[6], NODIR, 1) then
				if (ob6_count >= 4) then
					move_rush(units, OBJECTIVES[2])
				else
					defend_strong(units, OBJECTIVES[6], NODIR, 1, 100)
				end
			end
			if within(units, OBJECTIVES[2], NODIR, 1) then
				defend_normal(units, OBJECTIVES[2], NODIR, 1, 100)
			end
		else
			defend_normal(units, OBJECTIVES[9], NODIR, 1, 100)
		end
    end

    -- _SNIPER_1376 -- NVA Sniper
    do local units = _SNIPER_1376
		fire_direct_nearest_to_hex(units, "45,45", 100, true)
    end

    -- _NVA_ANTIAIRCRAFT_COY_64_127MM_PORTERS_1419 -- NVA Anti-Aircraft Company 64 - 12.7mm/Porters
    do local units = _NVA_AAMG_PLTN_1420
		fire_direct_nearest_to_hex(units, "47,45", 100, true)
    end
    do local units = _NVA_AAMG_PLTN_1421
			fire_direct_nearest_to_hex(units, "48,54", 100, true)
    end
    do local units = _NVA_AAMG_PLTN_1422
		local hex51_47_count = units_within_count("51,47", NODIR, 1, US_SIDE, true)
		local ob6_count = units_within_count(OBJECTIVES[6], NODIR, 1, US_SIDE, true)
		if (hex51_47_count >= 3) then 
			move_norush(units, OBJECTIVES[6])
		elseif (ob6_count >= 3) then 
			move_rush(units, "45,45")
		else
			fire_direct_nearest_to_hex(units, "51,47", 100, true)
		end
		if at(units, OBJECTIVES[6]) then
			fire_direct_nearest_to_hex(units, OBJECTIVES[6], 100, true)
		end	
		if at(units, "45,45") then
			fire_direct_nearest_to_hex(units, "45,45", 100, true)
		end	
    end
    do local units = _NVA_AAMG_PLTN_1423
		fire_direct_nearest_to_hex(units, "46,45", 100, true)
    end

    -- _NVA_RECONNAISSANCE_COY_67_1428 -- NVA Reconnaissance Company 67
    do local units = join({_NVA_RECONNAISSANCE_COY_67_1428,_DAC_CONG_1332})
		if turn >= 29 then
			local ob6_count = units_within_count(OBJECTIVES[6], NODIR, 1, US_SIDE, true)
			local ob9_count = units_within_count(OBJECTIVES[9], NODIR, 1, US_SIDE, true)
			local ob10_count = units_within_count(OBJECTIVES[10], NODIR, 1, US_SIDE, true)
			local ob12_count = units_within_count(OBJECTIVES[12], NODIR, 1, US_SIDE, true)
			if (ob6_count >= 1) and (ob6_count <= 3) then 
				attack_nearest_to_hex(units, OBJECTIVES[6], NODIR, 1, 100, ATTACK_STRONG, true)
			elseif owned(OBJECTIVES[6], US_SIDE) then
				attack_strong(units, OBJECTIVES[6], NODIR, 1, 100)
			elseif (ob9_count >= 1) and (ob9_count <= 3) then 
				attack_nearest_to_hex(units, OBJECTIVES[9], NODIR, 1, 100, ATTACK_STRONG, true)
			elseif owned(OBJECTIVES[9], US_SIDE) then
				attack_strong(units, OBJECTIVES[9], NODIR, 1, 100)
			elseif (ob10_count >= 1) and (ob10_count <= 3) then 
				attack_nearest_to_hex(units, OBJECTIVES[10], NODIR, 1, 100, ATTACK_STRONG, true)
			elseif owned(OBJECTIVES[10], US_SIDE) then
				attack_strong(units, OBJECTIVES[10], NODIR, 1, 100)
			elseif (ob12_count >= 1) and (ob12_count <= 3) then 
				attack_nearest_to_hex(units, OBJECTIVES[12], NODIR, 1, 100, ATTACK_STRONG, true)
			elseif owned(OBJECTIVES[12], US_SIDE) then
				attack_strong(units, OBJECTIVES[12], NODIR, 1, 100)
			else
				defend_strong(units, OBJECTIVES[10], NODIR, 1, 100)
			end
		elseif turn >= 10 and turn <= 28 then
			local hex51_45_count = units_within_count("51,45", NODIR, 1, US_SIDE, true)
			local hex52_46_count = units_within_count("52,46", NODIR, 1, US_SIDE, true)
			local ob8_count = units_within_count(OBJECTIVES[8], NODIR, 2, US_SIDE, true)
			if owned(OBJECTIVES[8], US_SIDE) then
				if (ob8_count >= 2) and (ob8_count <= 3) then 
					attack_nearest_to_hex(units, OBJECTIVES[8], NODIR, 2, 100, ATTACK_STRONG, true)
				elseif (ob8_count <= 1) then
					attack_strong(units, OBJECTIVES[8], NODIR, 1, 100)
				elseif (hex51_45_count >= 1) and (hex51_45_count <= 3) then
					attack_nearest_to_hex(units, "51,45", NODIR, 2, 100, ATTACK_STRONG, true)
				elseif (hex52_46_count >= 1) and (hex52_46_count <= 3) then
					attack_nearest_to_hex(units, "52,46", NODIR, 2, 100, ATTACK_STRONG, true)
				else
					defend_strong(units)
				end
			else
				local ob2_count = units_within_count(OBJECTIVES[2], NODIR, 1, US_SIDE, true)
				local ob3_count = units_within_count(OBJECTIVES[3], NODIR, 1, US_SIDE, true)
				if (ob2_count >= 4) then
					defend_normal(units, OBJECTIVES[2], NODIR, 1, 100)
				elseif (ob2_count >= 1) and (ob2_count <= 3) then 
					attack_nearest_to_hex(units, OBJECTIVES[2], NODIR, 2, 100, ATTACK_STRONG, true)
				elseif (ob3_count >= 1) and (ob3_count <= 3) then
					attack_nearest_to_hex(units, OBJECTIVES[3], NODIR, 2, 100, ATTACK_STRONG, true)
				else
					defend_normal(units)
				end
			end		
		else
			local ob2_count = units_within_count(OBJECTIVES[2], NODIR, 1, US_SIDE, true)
			local ob3_count = units_within_count(OBJECTIVES[3], NODIR, 1, US_SIDE, true)
			if (ob2_count >= 4) then
				defend_normal(units, OBJECTIVES[2], NODIR, 1, 100)
			elseif (ob2_count >= 1) and (ob2_count <= 3) then 
				attack_nearest_to_hex(units, OBJECTIVES[2], NODIR, 2, 100, ATTACK_STRONG, true)
			elseif (ob3_count >= 1) and (ob3_count <= 3)  then
				attack_nearest_to_hex(units, OBJECTIVES[3], NODIR, 2, 100, ATTACK_STRONG, true)
			else
				defend_normal(units)
			end	
		end
    end

    -- _NVA_MACHINE_GUN_COY_64_SVN_1440 -- NVA Machine Gun Company 64 - SVN
    do local units = _NVA_HMG_1441
		local hex52_46_count = units_within_count("52,46", NODIR, 1, US_SIDE, true)
		local ob6_count = units_within_count(OBJECTIVES[6], NODIR, 1, US_SIDE, true)
		if (hex52_46_count >= 3) then 
			move_norush(units, OBJECTIVES[6])
		elseif (ob6_count >= 3) then 
			move_rush(units, "48,44")
		else
			fire_direct_nearest_to_hex(units, "52,46", 100, true)
		end
		if at(units, OBJECTIVES[6]) then
			fire_direct_nearest_to_hex(units, OBJECTIVES[6], 100, true)
		end
		if at(units, "48,44") then
			fire_direct_nearest_to_hex(units, "48,44", 100, true)
		end
    end
    do local units = _NVA_HMG_1442
		local hex51_49_count = units_within_count("51,49", NODIR, 1, US_SIDE, true)
		local hex51_47_count = units_within_count("51,47", NODIR, 1, US_SIDE, true)
		local ob6_count = units_within_count(OBJECTIVES[9], NODIR, 1, US_SIDE, true)
		if (hex51_49_count >= 3) then 
			move_norush(units, "51,47")
		elseif (hex51_47_count >= 3) then 
			move_norush(units, OBJECTIVES[9])
		elseif (ob6_count >= 4) then 
			move_rush(units, "49,45")
		else
			fire_direct_nearest_to_hex(units, "51,49", 100, true)
		end
		if at(units, "51,47") then
			fire_direct_nearest_to_hex(units, "51,47", 100, true)
		end
		if at(units, OBJECTIVES[6]) then
			fire_direct_nearest_to_hex(units, OBJECTIVES[6], 100, true)
		end
		if at(units, "49,45") then
			fire_direct_nearest_to_hex(units, "49,45", 100, true)
		end
    end
    do local units = _NVA_HMG_1443
		local ob1_count = units_within_count(OBJECTIVES[1], NODIR, 3, US_SIDE, true)
		if (ob1_count >= 1) then 
			move_norush(units, OBJECTIVES[1])
		else
			fire_direct_nearest_to_hex(units, "44,49", 100, true)
		end
		if at(units, OBJECTIVES[1]) then
			fire_direct_nearest_to_hex(units, OBJECTIVES[1], 100, true)
		end
    end
    
    -- _NVA_RECOILLESS_RIFLE_COY_64_B10_1444 -- NVA Recoilless Rifle Company 64 - B-10
    do local units = _B10_1445
		fire_direct_nearest_to_hex(units, "54,49", 100, true)
    end
    do local units = _B10_1446
		local ob1_count = units_within_count(OBJECTIVES[1], NODIR, 3, US_SIDE, true)
		if (ob1_count >= 1) then 
			move_norush(units,OBJECTIVES[1])
		else
			fire_direct_nearest_to_hex(units, "44,49", 100, true)
		end
		if at(units, OBJECTIVES[1]) then
			fire_direct_nearest_to_hex(units, OBJECTIVES[1], 100, true)
		end
    end

    -- _MORTAR_BTY_64_82MMX9_1449 -- Mortar Battery 64 - 82mmx9
    -- _82MM_MORTARS_1450 -- 82mm Mortars
    do local units = _82MM_MORTARS_1450
		local ob1_count = units_within_count(OBJECTIVES[1], NODIR, 3, US_SIDE, true)
		local ob2_count = units_within_count(OBJECTIVES[2], NODIR, 2, US_SIDE, true)
		local ob3_count = units_within_count(OBJECTIVES[3], NODIR, 1, US_SIDE, true)
		local ob4_count = units_within_count(OBJECTIVES[4], NODIR, 3, US_SIDE, true)
		if (ob1_count >= 1) then 
			fire_indirect_nearest_to_hex(units, OBJECTIVES[1], 100, true)
		elseif (ob2_count >= 1) then 
			fire_indirect_nearest_to_hex(units, OBJECTIVES[1], 100, true)	
		elseif (ob3_count >= 1) then 
			fire_indirect_nearest_to_hex(units, OBJECTIVES[1], 100, true)
		elseif (ob4_count >= 1) then 
			fire_indirect_nearest_to_hex(units, OBJECTIVES[1], 100, true)
		else
			fire_indirect_nearest_to_hex(units, "45,49", 100, true)
		end
    end

    -- _AAMG_1468 -- NVA Anti-Aircraft Machine Gun
    do local units = _AAMG_1468
		fire_direct_nearest_to_hex(units, "48,52", 100, true)
    end

    
    do local units = _TRAILPORTERS_1454
		move_way_point(units, {"16,48","20,50","26,50","34,52","39,53","41,50","43,46"}, NODIR, 1, 100, true)
        if within(units, "43,46", NODIR, 1) then
            defend_weak(units, "43,46", NODIR, 1, 100)
		end
    end
    do local units = _TRAILPORTERS_1455
    	if turn >= 10 then
			move_way_point(units, {"16,48","20,50","26,50","34,52","39,53","41,50","43,46"}, NODIR, 1, 100, true)
		end
        if within(units, "43,46", NODIR, 1) then
            defend_weak(units, "43,46", NODIR, 1, 100)
		end
    end
    

end

------------------------------------------------------------------------------------------------------------------------

function on_objective_capture (hc, value, values, side) -- DO NOT REMOVE

	if owned({OBJECTIVES[4],OBJECTIVES[4],OBJECTIVES[4]}, US_SIDE) then
            dialog_once("Capture of Hill 881 South",
                "Congratulations for securing Hill 881 South!\n" ..
                "\n" ..
                "Use your helicopters to transport one of the supply caches to the Landing Zone at HEX 51,54 for a supply boost!\n" ..
                "\n" ..
                "\n" ..
                "a", "a")
	end

	if owned({OBJECTIVES[10],OBJECTIVES[12],OBJECTIVES[13]}, US_SIDE) then
            dialog_once("Capture of Hill 861",
                "Congratulations for securing Hill 861!\n" ..
                "\n" ..
                "Use your helicopters to transport one of the supply caches to the Landing Zone at HEX 57,52 for a supply boost!\n" ..
                "\n" ..
                "\n" ..
                "a", "a")
	end

	if chance(22) then -- chance for player receiving a shout
	
		if side == US_SIDE then
			dialog("Commendations", US_COMMENDATIONS[dieroll(#US_COMMENDATIONS)], side, side)
		else
			dialog("Commendations", NVA_COMMENDATIONS[dieroll(#NVA_COMMENDATIONS)], side, side)
		end
	end

end

------------------------------------------------------------------------------------------------------------------------

function on_unit_move (hc_from, hc_to, trackid) -- DO NOT REMOVE



-- If supply unit arrives where instructed
    if ((hc_to == "51,54") and (trackid == 71)) or ((hc_to == "51,54") and (trackid == 72)) then
        if not SUPPLY_881_ARRIVES then
			inc_ammo_level(US_SIDE, 22)
			inc_arty_ammo_level(US_SIDE, 16)
            dialog_once("Supply Arrival Hill 881 South",
                "Your supply situation has now improved! Excellent job following orders!\n" ..
                "\n" ..
                "Your base Ammo level is improved by 22 and your Artillery Ammo level is improved by 16!\n" ..
                "\n" ..
                "\n" ..
                "a", "a")
            SUPPLY_881_ARRIVES = true 
        end 
    end 
    if ((hc_to == "57,52") and (trackid == 72)) or ((hc_to == "57,52") and (trackid == 72)) then
        if not SUPPLY_861_ARRIVES then
			inc_ammo_level(US_SIDE, 24)
			inc_arty_ammo_level(US_SIDE, 18)
            dialog_once("Supply Arrival Hill 861",
                "Your supply situation has now improved! Excellent job following orders!\n" ..
                "\n" ..
                "Your base Ammo level is improved by 24 and your Artillery Ammo level is improved by 18!\n" ..
                "\n" ..
                "\n" ..
                "a", "a")
            SUPPLY_861_ARRIVES = true 
        end 
    end 
    
-- If supply unit arrives where instructed
    if ((hc_to == "43,46") and (trackid == 1454)) then
        if not SUPPLY_1454_ARRIVES then
			inc_ammo_level(NVA_SIDE, 20)
			inc_arty_ammo_level(NVA_SIDE, 10)
            dialog_once("Supply Arrival Trailporters 1",
                "Your supply situation has now improved! Excellent job following orders!\n" ..
                "\n" ..
                "Your base Ammo level is improved by 22 and your Artillery Ammo level is improved by 16!\n" ..
                "\n" ..
                "\n" ..
                NVA_SIDE, NVA_SIDE)
            SUPPLY_1454_ARRIVES = true 
        end 
    end 
    if ((hc_to == "43,46") and (trackid == 1455)) then
        if not SUPPLY_1455_ARRIVES then
			inc_ammo_level(NVA_SIDE, 22)
			inc_arty_ammo_level(NVA_SIDE, 10)
            dialog_once("Supply Arrival Trailporters 2",
                "Your supply situation has now improved! Excellent job following orders!\n" ..
                "\n" ..
                "Your base Ammo level is improved by 22 and your Artillery Ammo level is improved by 16!\n" ..
                "\n" ..
                "\n" ..
                NVA_SIDE, NVA_SIDE)
            SUPPLY_1455_ARRIVES = true 
        end 
    end 


end 

------------------------------------------------------------------------------------------------------------------------

function on_unit_fire (hc, trackid, pid, name, side, nation, oid, orgname, strength) -- DO NOT REMOVE


    if side == SIDE_A then
        SIDE_A_FIRED = true
    elseif side == SIDE_B then
        SIDE_B_FIRED = true
    end


end

------------------------------------------------------------------------------------------------------------------------

function on_unit_arty_fire (hc, trackid, pid, name, side, nation, oid, orgname, strength) -- DO NOT REMOVE


    if side == SIDE_A then
        SIDE_A_ARTY_FIRED = true
    elseif side == SIDE_B then
        SIDE_B_ARTY_FIRED = true
    end


end

------------------------------------------------------------------------------------------------------------------------

function on_unit_attack (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader, attype) -- DO NOT REMOVE


    -- lose EPs for friendly fire arty or air attacks only
    if side == current_side() then -- side is the target side
        if attype == INDIRECTFIRE_COMBAT then
            inc_event_points(side, -5)
        elseif attype == AIRSTRIKE_COMBAT then
            inc_event_points(side, -10)
        end
    end


end

------------------------------------------------------------------------------------------------------------------------

function on_unit_reduce (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader, loss, combat) -- DO NOT REMOVE 


    if has_flag(counter_unit_other_flags(trackid), HELICOPTER) then
        inc_event_points(NVA_SIDE, 25*loss)
        dialog("Notice", "For destroying " .. loss .. " helicopter" .. (((loss > 1) and "s") or "") .. ", the North Vietnamese side gains " .. 25*loss .. " EPs.", NVA_SIDE, NVA_SIDE)
    end

    company_reduce_check(trackid, US_COYS, {"American","North Vietnamese"}, {0,100}, {{NONATION},{NONATION}}, {0,0}, 50, both_sides(), both_sides())

    company_reduce_check(trackid, NVA_COYS, {"North Vietnamese","American"}, {0,50}, {{NONATION},{NONATION}}, {0,0}, 50, both_sides(), both_sides())

end 

------------------------------------------------------------------------------------------------------------------------

function on_unit_kill (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE


    do local units = join({_BRG_HQ_216, _BTN_HQ_117, _2ND_3RD_MARINE_118, _BTN_HQ_156, _3RD_3RD_MARINE_157, _HQ_2, _US_ADVISOR_42, _HQ_561, _US_ADVISOR_593})
       local award = 25
        if member(trackid, units) then
            inc_event_points(NVA_SIDE, award)
            dialog("Notice", "For destroying the " .. counter_name(trackid) .. ", the North Vietnamese side gains " .. award .. " EPs.", NVA_SIDE, NVA_SIDE)
        end
    end

    do local units = join({_SUPPLY_CACHE_71, _SUPPLY_CACHE_72, _SUPPLY_TRUCKS_188})
       local award = 35
        if member(trackid, units) then
            inc_event_points(NVA_SIDE, award)
            dialog("Notice", "For destroying the " .. counter_name(trackid) .. ", the North Vietnamese side gains " .. award .. " EPs.", NVA_SIDE, NVA_SIDE)
        end
    end

    do local units = join({_M101_105MM_HOWITZERS_2161, _M114_155MM_HOWITZERS_525, _M101_105MM_HOWITZERS_523, _42_INCH_MORTARS_530})
       local award = 40
        if member(trackid, units) then
            inc_event_points(NVA_SIDE, award)
            dialog("Notice", "For destroying the " .. counter_name(trackid) .. ", the North Vietnamese side gains " .. award .. " EPs.", NVA_SIDE, NVA_SIDE)
        end
    end

    do local units = join({_TRUNG_DOAN_HQ_1291, _R18C_1292, _TIEU_DOAN_HQ_1294, _D7_R18C_2100, _TIEU_DOAN_HQ_1336, _D8_R18C_2105})
       local award = 25
        if member(trackid, units) then
            inc_event_points(US_SIDE, award)
            dialog("Notice", "For destroying the " .. counter_name(trackid) .. ", the American side gains " .. award .. " EPs.", US_SIDE, US_SIDE)
        end
    end

    do local units = join({_TRAILPORTERS_1454, _TRAILPORTERS_1455})
       local award = 35
        if member(trackid, units) then
            inc_event_points(US_SIDE, award)
            dialog("Notice", "For destroying the " .. counter_name(trackid) .. ", the American side gains " .. award .. " EPs.", US_SIDE, US_SIDE)
        end
    end

    do local units = join({_AAMG_1468, _NVA_AAMG_PLTN_1420, _NVA_AAMG_PLTN_1421, _NVA_AAMG_PLTN_1422, _NVA_AAMG_PLTN_1423})
       local award = 15
        if member(trackid, units) then
            inc_event_points(US_SIDE, award)
            dialog("Notice", "For destroying the " .. counter_name(trackid) .. ", the American side gains " .. award .. " EPs.", US_SIDE, US_SIDE)
        end
    end


    company_kill_check(trackid, US_COYS, {"American","North Vietnamese"}, {0,200}, {{NONATION},{NONATION}}, {0,0}, both_sides(), both_sides())

    company_kill_check(trackid, NVA_COYS, {"North Vietnamese","American"}, {0,100}, {{NONATION},{NONATION}}, {0,0}, both_sides(), both_sides())


end

------------------------------------------------------------------------------------------------------------------------

function on_unit_reinforce (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE
    


end

------------------------------------------------------------------------------------------------------------------------

-- NOTE:  there are no hc hex coordinates for on_unit_release()

function on_unit_release (trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_unit_remove (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

-- NOTE:  0 is superior (surviving) unit, 1 is subordinate (disappearing) unit

function on_unit_merge (hc, trackid0, pid0, name0, side0, nation0, oid0, orgname0, points0, strength0, HQ0, Leader0, trackid1, pid1, name1, side1, nation1, oid1, orgname1, points1, strength1, HQ1, Leader1) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_unit_to_top (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE
    


end

------------------------------------------------------------------------------------------------------------------------

function on_unit_to_bottom (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE
    


end

------------------------------------------------------------------------------------------------------------------------

function on_unit_clockwise (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE
    


end

------------------------------------------------------------------------------------------------------------------------

function on_unit_counterclockwise (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE
    


end

------------------------------------------------------------------------------------------------------------------------ 

function on_hex_attack (hc, side, nation, attype) -- DO NOT REMOVE

--[[ commonly used; uncomment and adapt as necessary:
    -- lose EPs for indirect fire or airstrike vs. inhabited hex (village, city, suburb), whether or not occupied by the enemy
    -- side is the firing side
    -- FREE FIRE ZONE
    if -- is_building_hex(hc) or
       is_habitat_hex(hc) then
        if not_occupied(hc, other_side(side)) then
            if attype == INDIRECTFIRE_COMBAT then
                inc_event_points(side, -2)
            elseif attype == AIRSTRIKE_COMBAT then
                inc_event_points(side, -5)
            end
        else -- occupied
            if attype == INDIRECTFIRE_COMBAT then
                inc_event_points(side, -1)
            elseif attype == AIRSTRIKE_COMBAT then
                inc_event_points(side, -2)
            end
        end
    end
--]]

end

------------------------------------------------------------------------------------------------------------------------ 

function on_hex_assault (hc, side) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_air_attack (hc, pid, name, side, nation, points, strength) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_arty_attack (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------ 

function on_mine_attack (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE 



end 

------------------------------------------------------------------------------------------------------------------------

function on_ied_attack (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE 



end 

------------------------------------------------------------------------------------------------------------------------

function on_build_vehicle_bridge (hc, dir, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_build_light_bridge (hc, dir, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_lay_mine_field (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_set_ied (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_build_barrier (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_damage (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_improve_hex (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_entrench_hex (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_clear_lz (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_clear_hex (hc) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------
